[Libreoffice-commits] core.git: sc/inc

2017-11-26 Thread Tor Lillqvist
 sc/inc/conditio.hxx |   92 
 1 file changed, 92 insertions(+)

New commits:
commit e2277ac677103255e4b2a79ccb32cb819f41d175
Author: Tor Lillqvist 
Date:   Thu Nov 23 20:53:42 2017 +0200

Add debug output operator<< for ScConditionMode

Change-Id: I031d080dc8cbfcc5619bf7d5ee6112dde0a2ef04
Reviewed-on: https://gerrit.libreoffice.org/45277
Tested-by: Jenkins 
Reviewed-by: Tor Lillqvist 

diff --git a/sc/inc/conditio.hxx b/sc/inc/conditio.hxx
index bad7b3dba18c..7ca023a801f5 100644
--- a/sc/inc/conditio.hxx
+++ b/sc/inc/conditio.hxx
@@ -86,6 +86,98 @@ enum class ScConditionMode
 NONE
 };
 
+// For use in SAL_DEBUG etc. Output format not guaranteed to be stable.
+template
+inline std::basic_ostream & operator 
<<(std::basic_ostream & stream, const ScConditionMode& rMode)
+{
+switch (rMode)
+{
+case ScConditionMode::Equal:
+stream << "EQUAL";
+break;
+case ScConditionMode::Less:
+stream << "LESS";
+break;
+case ScConditionMode::Greater:
+stream << "GREATER";
+break;
+case ScConditionMode::EqLess:
+stream << "EQLESS";
+break;
+case ScConditionMode::EqGreater:
+stream << "EQGREATER";
+break;
+case ScConditionMode::NotEqual:
+stream << "NOTEQUAL";
+break;
+case ScConditionMode::Between:
+stream << "BETWEEN";
+break;
+case ScConditionMode::NotBetween:
+stream << "NOTBETWEEN";
+break;
+case ScConditionMode::Duplicate:
+stream << "DUPLICATE";
+break;
+case ScConditionMode::NotDuplicate:
+stream << "NOTDUPLICATE";
+break;
+case ScConditionMode::Direct:
+stream << "DIRECT";
+break;
+case ScConditionMode::Top10:
+stream << "TOP10";
+break;
+case ScConditionMode::Bottom10:
+stream << "BOTTOM10";
+break;
+case ScConditionMode::TopPercent:
+stream << "TOPPERCENT";
+break;
+case ScConditionMode::BottomPercent:
+stream << "BOTTOMPERCENT";
+break;
+case ScConditionMode::AboveAverage:
+stream << "ABOVEAVERAGE";
+break;
+case ScConditionMode::BelowAverage:
+stream << "BELOWAVERAGE";
+break;
+case ScConditionMode::AboveEqualAverage:
+stream << "ABOVEEQUALAVERAGE";
+break;
+case ScConditionMode::BelowEqualAverage:
+stream << "BELOWEQUALAVERAGE";
+break;
+case ScConditionMode::Error:
+stream << "ERROR";
+break;
+case ScConditionMode::NoError:
+stream << "NOERROR";
+break;
+case ScConditionMode::BeginsWith:
+stream << "BEGINSWITH";
+break;
+case ScConditionMode::EndsWith:
+stream << "ENDSWITH";
+break;
+case ScConditionMode::ContainsText:
+stream << "CONTAINSTEXT";
+break;
+case ScConditionMode::NotContainsText:
+stream << "NOTCONTAINSTEXT";
+break;
+case ScConditionMode::NONE:
+stream << "NONE";
+break;
+default:
+stream << "?(" << (int)rMode << ")";
+break;
+}
+
+return stream;
+}
+
 class ScFormulaListener : public SvtListener
 {
 private:
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: RepositoryExternal.mk xmlsecurity/Library_xsec_xmlsec.mk

2017-11-26 Thread David Tardon
 RepositoryExternal.mk  |   14 ++
 xmlsecurity/Library_xsec_xmlsec.mk |6 +-
 2 files changed, 15 insertions(+), 5 deletions(-)

New commits:
commit 7c77ff5dd2d0573a56f8b59dc9113c23e0ea29c9
Author: David Tardon 
Date:   Fri Nov 24 10:44:42 2017 +0100

move conditional stuff to RepositoryExternal.mk

Change-Id: I33e299277c53e8e2b8ab7e4cdf52d2487f90b51b
Reviewed-on: https://gerrit.libreoffice.org/45211
Tested-by: Jenkins 
Reviewed-by: David Tardon 

diff --git a/RepositoryExternal.mk b/RepositoryExternal.mk
index bb3c9b6895e0..bdc5d65a2d81 100644
--- a/RepositoryExternal.mk
+++ b/RepositoryExternal.mk
@@ -3451,6 +3451,8 @@ endef
 
 endif # ENABLE_BREAKPAD
 
+ifeq ($(ENABLE_GPGMEPP),TRUE)
+
 ifneq ($(SYSTEM_GPGMEPP),)
 
 gb_ExternalProject__use_gpgmepp:=
@@ -3567,6 +3569,18 @@ endif
 
 endif
 
+else # !ENABLE_GPGMEPP
+
+gb_ExternalProject__use_gpgmepp :=
+gb_ExternalProject__use_libassuan :=
+gb_ExternalProject__use_libgpg-error :=
+
+gb_LinkTarget__use_gpgmepp :=
+gb_LinkTarget__use_libassuan :=
+gb_LinkTarget__use_libgpg-error :=
+
+endif # ENABLE_GPGMEPP
+
 define gb_LinkTarget__use_dconf
 $(call gb_LinkTarget_add_defs,$(1),$(DCONF_CFLAGS))
 $(call gb_LinkTarget_add_libs,$(1),$(DCONF_LIBS))
diff --git a/xmlsecurity/Library_xsec_xmlsec.mk 
b/xmlsecurity/Library_xsec_xmlsec.mk
index ee2f9da7bb1b..1ef27dbc6602 100644
--- a/xmlsecurity/Library_xsec_xmlsec.mk
+++ b/xmlsecurity/Library_xsec_xmlsec.mk
@@ -55,14 +55,10 @@ endif
 
 $(eval $(call gb_Library_use_externals,xsec_xmlsec,\
boost_headers \
+   gpgmepp \
libxml2 \
xmlsec \
 ))
-ifeq ($(ENABLE_GPGMEPP),TRUE)
-$(eval $(call gb_Library_use_externals,xsec_xmlsec,\
-   gpgmepp \
-))
-endif
 
 $(eval $(call gb_Library_add_exception_objects,xsec_xmlsec,\
xmlsecurity/source/xmlsec/biginteger \
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


IDE integration with qtcreator

2017-11-26 Thread Heiko Tietze
Trying to setup an IDE environment but after "make qtcreator-ide-integration" 
the build fails as system include files are not found. For example in case of 
sc "libxml/xpathInternals.h: No such file or directory" (exists at 
/usr/include/libxml2/libxml/). Same happens now for make from bash while it 
worked before. Removing all .pro and *.pro.user solves it for bash but isn't 
helpful for qtcreator. Guess there is a path variable missing, but what and 
where?

Arch Linux, LXQt



signature.asc
Description: OpenPGP digital signature
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: chart2/source

2017-11-26 Thread Julien Nabet
 chart2/source/view/main/OpenGLRender.cxx |   32 ++-
 chart2/source/view/main/OpenGLRender.hxx |   14 ++---
 2 files changed, 18 insertions(+), 28 deletions(-)

New commits:
commit d8c0051c6c0400aae6e0a440e83c2c29979347f7
Author: Julien Nabet 
Date:   Sun Nov 26 11:28:49 2017 +0100

Replace lists by vectors in chart2

Change-Id: I634363fb881776a089d4bcca366c8caebcdde117
Reviewed-on: https://gerrit.libreoffice.org/45283
Tested-by: Jenkins 
Reviewed-by: Julien Nabet 

diff --git a/chart2/source/view/main/OpenGLRender.cxx 
b/chart2/source/view/main/OpenGLRender.cxx
index 2d8d816d6a47..788d5e9fc45f 100644
--- a/chart2/source/view/main/OpenGLRender.cxx
+++ b/chart2/source/view/main/OpenGLRender.cxx
@@ -191,15 +191,13 @@ int OpenGLRender::RenderLine2FBO()
 {
 CHECK_GL_ERROR();
 glLineWidth(m_fLineWidth);
-size_t listNum = m_Line2DShapePointList.size();
 PosVecf3 const trans = {0.0f, 0.0f, 0.0f};
 PosVecf3 const angle = {0.0f, 0.0f, 0.0f};
 PosVecf3 const scale = {1.0f, 1.0f, 1.0f};
 MoveModelf(trans, angle, scale);
 m_MVP = m_Projection * m_View * m_Model;
-for (size_t i = 0; i < listNum; i++)
+for (auto const& pointList : m_Line2DShapePointList)
 {
-PointList &pointList = m_Line2DShapePointList.front();
 //fill vertex buffer
 glBindBuffer(GL_ARRAY_BUFFER, m_VertexBuffer);
 CHECK_GL_ERROR();
@@ -230,8 +228,8 @@ int OpenGLRender::RenderLine2FBO()
 glUseProgram(0);
 glDisableVertexAttribArray(m_2DVertexID);
 CHECK_GL_ERROR();
-m_Line2DShapePointList.pop_front();
 }
+m_Line2DShapePointList.clear();
 CHECK_GL_ERROR();
 CHECK_GL_FRAME_BUFFER_STATUS();
 m_fZStep += Z_STEP;
@@ -416,11 +414,9 @@ int OpenGLRender::RenderBubble2FBO()
 {
 CHECK_GL_ERROR();
 glm::vec4 edgeColor = glm::vec4(0.0, 0.0, 0.0, 1.0);
-size_t listNum = m_Bubble2DShapePointList.size();
-for (size_t i = 0; i < listNum; i++)
+for (auto const& pointList : m_Bubble2DShapePointList)
 {
 //move the circle to the pos, and scale using the xScale and Y scale
-Bubble2DPointList &pointList = m_Bubble2DShapePointList.front();
 PosVecf3 const trans = {pointList.x, pointList.y, m_fZStep};
 PosVecf3 const angle = {0.0f, 0.0f, 0.0f};
 PosVecf3 const scale = {pointList.xScale / 2, pointList.yScale / 2 , 
1.0f};
@@ -476,9 +472,9 @@ int OpenGLRender::RenderBubble2FBO()
 glDisableVertexAttribArray(m_2DVertexID);
 glUseProgram(0);
 glBindBuffer(GL_ARRAY_BUFFER, 0);
-m_Bubble2DShapePointList.pop_front();
 glLineWidth(m_fLineWidth);
 }
+m_Bubble2DShapePointList.clear();
 //if use MSAA, we should copy the data to the FBO texture
 GLenum fbResult = glCheckFramebufferStatus(GL_FRAMEBUFFER);
 if( fbResult != GL_FRAMEBUFFER_COMPLETE )
@@ -514,11 +510,9 @@ int OpenGLRender::RectangleShapePoint(float x, float y, 
float directionX, float
 
 int OpenGLRender::RenderRectangleShape(bool bBorder, bool bFill)
 {
-size_t listNum = m_RectangleShapePointList.size();
-for (size_t i = 0; i < listNum; i++)
+for (auto const& pointList : m_RectangleShapePointList)
 {
 //move the circle to the pos, and scale using the xScale and Y scale
-RectanglePointList &pointList = m_RectangleShapePointList.front();
 {
 PosVecf3 const trans = {0, 0, 0};
 PosVecf3 const angle = {0.0f, 0.0f, 0.0f};
@@ -614,8 +608,8 @@ int OpenGLRender::RenderRectangleShape(bool bBorder, bool 
bFill)
 glDisableVertexAttribArray(m_BackgroundColorID);
 glUseProgram(0);
 glBindBuffer(GL_ARRAY_BUFFER, 0);
-m_RectangleShapePointList.pop_front();
 }
+m_RectangleShapePointList.clear();
 CHECK_GL_ERROR();
 
 m_fZStep += Z_STEP;
@@ -693,17 +687,15 @@ int OpenGLRender::CreateTextTexture(const 
boost::shared_array &rPixel
 CHECK_GL_ERROR();
 glBindTexture(GL_TEXTURE_2D, 0);
 CHECK_GL_ERROR();
-m_TextInfoList.push_back(aTextInfo);
+m_TextInfoVector.push_back(aTextInfo);
 return 0;
 }
 
 int OpenGLRender::RenderTextShape()
 {
 CHECK_GL_ERROR();
-size_t listNum = m_TextInfoList.size();
-for (size_t i = 0; i < listNum; i++)
+for (auto const& textInfo : m_TextInfoVector)
 {
-TextInfo &textInfo = m_TextInfoList.front();
 PosVecf3 const trans = { textInfo.nDx, textInfo.nDy, 0};
 PosVecf3 const angle = {0.0f, 0.0f, float(textInfo.rotation)};
 PosVecf3 const scale = {1.0, 1.0, 1.0f};
@@ -757,8 +749,8 @@ int OpenGLRender::RenderTextShape()
 glUseProgram(0);
 glDeleteTextures(1, &textInfo.texture);
 CHECK_GL_ERROR();
-m_TextInfoList.pop_front();
 }
+m_TextInfoVector.clear();
 CHECK_GL_ERROR();
 m_fZStep += Z_STEP;
 return 0;
@@ -812,15 +804,13 @@ int OpenGLRender::RenderArea2DShape()
 CHECK_GL_ERROR();

[Libreoffice-commits] core.git: xmloff/source

2017-11-26 Thread Julien Nabet
 xmloff/source/chart/SchXMLChartContext.cxx |   30 +++
 xmloff/source/chart/SchXMLChartContext.hxx |5 -
 xmloff/source/chart/SchXMLPlotAreaContext.cxx  |   16 ++--
 xmloff/source/chart/SchXMLPlotAreaContext.hxx  |8 +-
 xmloff/source/chart/SchXMLRegressionCurveObjectContext.cxx |8 +-
 xmloff/source/chart/SchXMLRegressionCurveObjectContext.hxx |4 -
 xmloff/source/chart/SchXMLSeries2Context.cxx   |   50 ++---
 xmloff/source/chart/SchXMLSeries2Context.hxx   |   10 +-
 8 files changed, 66 insertions(+), 65 deletions(-)

New commits:
commit 459caa059d75260ba1e83ce4ef47cd901b2dbfbf
Author: Julien Nabet 
Date:   Sun Nov 26 12:13:41 2017 +0100

Replace some lists by vectors in xmloff

Change-Id: Ib321b4716ee95507b9d51ad8320bc7eb7cf35c93
Reviewed-on: https://gerrit.libreoffice.org/45284
Tested-by: Jenkins 
Reviewed-by: Julien Nabet 

diff --git a/kit/Kit.cpp b/kit/Kit.cpp
index df2d6ce5..aae8acf6 100644
--- a/kit/Kit.cpp
+++ b/kit/Kit.cpp
@@ -17,6 +17,9 @@
 #include 
 #include 
 #include 
+#ifdef __GLIBC__
+#include 
+#endif
 #include 
 #include 
 #include 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sc/inc

2017-11-26 Thread Tor Lillqvist
 sc/inc/conditio.hxx |   27 +++
 1 file changed, 27 insertions(+)

New commits:
commit 752d263c36b3de9d9a0247df46216c610a5c48ed
Author: Tor Lillqvist 
Date:   Fri Nov 24 22:41:20 2017 +0200

Add debug output operator<< for ScFormatEntry::Type

Change-Id: I4e23f17a59e995d76258420f07818079c7a9b94b
Reviewed-on: https://gerrit.libreoffice.org/45288
Tested-by: Jenkins 
Reviewed-by: Tor Lillqvist 

diff --git a/sc/inc/conditio.hxx b/sc/inc/conditio.hxx
index 7ca023a801f5..b619e1545e97 100644
--- a/sc/inc/conditio.hxx
+++ b/sc/inc/conditio.hxx
@@ -252,6 +252,33 @@ protected:
 
 };
 
+template
+inline std::basic_ostream & operator 
<<(std::basic_ostream & stream, const ScFormatEntry::Type& rType)
+{
+switch (rType)
+{
+case ScFormatEntry::Type::Condition:
+stream << "Condition";
+break;
+case ScFormatEntry::Type::Colorscale:
+stream << "Colorscale";
+break;
+case ScFormatEntry::Type::Databar:
+stream << "Databar";
+break;
+case ScFormatEntry::Type::Iconset:
+stream << "Iconset";
+break;
+case ScFormatEntry::Type::Date:
+stream << "Data";
+break;
+default:
+stream << "?(" << (int)rType << ")";
+break;
+}
+return stream;
+}
+
 class approx_less
 {
 public:
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: bridges/source

2017-11-26 Thread David Tardon
 bridges/source/cpp_uno/gcc3_linux_aarch64/abi.cxx |2 +-
 bridges/source/cpp_uno/gcc3_linux_aarch64/callvirtualfunction.cxx |2 +-
 bridges/source/cpp_uno/gcc3_linux_aarch64/cpp2uno.cxx |2 +-
 bridges/source/cpp_uno/gcc3_linux_aarch64/uno2cpp.cxx |4 ++--
 4 files changed, 5 insertions(+), 5 deletions(-)

New commits:
commit 897c07bda2d116bcc2fa4a64c1eb75a52651c991
Author: David Tardon 
Date:   Sun Nov 26 16:04:25 2017 +0100

fix includes in aarch64 bridge

Change-Id: Ia27f15483c27bc43a3cd3a74432f15fa928ad6da

diff --git a/bridges/source/cpp_uno/gcc3_linux_aarch64/abi.cxx 
b/bridges/source/cpp_uno/gcc3_linux_aarch64/abi.cxx
index fa6ffebfbc17..da22eb436b8f 100644
--- a/bridges/source/cpp_uno/gcc3_linux_aarch64/abi.cxx
+++ b/bridges/source/cpp_uno/gcc3_linux_aarch64/abi.cxx
@@ -38,7 +38,7 @@
 #include 
 #include 
 
-#include 
+#include "abi.hxx"
 #include 
 #include 
 
diff --git a/bridges/source/cpp_uno/gcc3_linux_aarch64/callvirtualfunction.cxx 
b/bridges/source/cpp_uno/gcc3_linux_aarch64/callvirtualfunction.cxx
index 09f7696cfb4a..2f7188ea4f99 100644
--- a/bridges/source/cpp_uno/gcc3_linux_aarch64/callvirtualfunction.cxx
+++ b/bridges/source/cpp_uno/gcc3_linux_aarch64/callvirtualfunction.cxx
@@ -24,7 +24,7 @@
 #include 
 #include 
 
-#include 
+#include "callvirtualfunction.hxx"
 
 void callVirtualFunction(
 unsigned long function, unsigned long * gpr, unsigned long * fpr,
diff --git a/bridges/source/cpp_uno/gcc3_linux_aarch64/cpp2uno.cxx 
b/bridges/source/cpp_uno/gcc3_linux_aarch64/cpp2uno.cxx
index 3d8eea4503e9..d867a04dd299 100644
--- a/bridges/source/cpp_uno/gcc3_linux_aarch64/cpp2uno.cxx
+++ b/bridges/source/cpp_uno/gcc3_linux_aarch64/cpp2uno.cxx
@@ -40,7 +40,7 @@
 #include 
 #include 
 
-#include 
+#include "abi.hxx"
 
 extern "C" void vtableSlotCall_();
 
diff --git a/bridges/source/cpp_uno/gcc3_linux_aarch64/uno2cpp.cxx 
b/bridges/source/cpp_uno/gcc3_linux_aarch64/uno2cpp.cxx
index 4e7d69b0a871..8faccbf3edaf 100644
--- a/bridges/source/cpp_uno/gcc3_linux_aarch64/uno2cpp.cxx
+++ b/bridges/source/cpp_uno/gcc3_linux_aarch64/uno2cpp.cxx
@@ -42,8 +42,8 @@
 #include 
 #include 
 
-#include 
-#include 
+#include "abi.hxx"
+#include "callvirtualfunction.hxx"
 
 namespace {
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Arch Coal Inc

2017-11-26 Thread Khun Simon
Hello How are you doing, It have been a long time since we last have contact,I 
was away for a business trip However, kindly send your latest cataloger so that 
we can choose from there and place our new order as soon as possible. This 
order is required in our Thailand branch. Regards, Khun Simon Arch Coal Inc. 
Contact us via our email address: sale...@baryet.net One City Place Driv Suit 
300 St. Louis MO63141___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: xmloff/source

2017-11-26 Thread Julien Nabet
 xmloff/source/chart/SchXMLChartContext.cxx   |   57 ---
 xmloff/source/chart/SchXMLSeries2Context.cxx |  131 ---
 2 files changed, 80 insertions(+), 108 deletions(-)

New commits:
commit ae3a10fc86620250363724d5634c09a9f61f91be
Author: Julien Nabet 
Date:   Sun Nov 26 15:53:36 2017 +0100

Modernize by using for-range loops (xmloff/chart)

Change-Id: I505ac79e76738ce39d1768451e7c213246eec88d
Reviewed-on: https://gerrit.libreoffice.org/45289
Reviewed-by: Noel Grandin 
Tested-by: Jenkins 
Reviewed-by: Julien Nabet 

diff --git a/xmloff/source/chart/SchXMLChartContext.cxx 
b/xmloff/source/chart/SchXMLChartContext.cxx
index 0bc45256a597..10f3c9345e16 100644
--- a/xmloff/source/chart/SchXMLChartContext.cxx
+++ b/xmloff/source/chart/SchXMLChartContext.cxx
@@ -481,12 +481,10 @@ struct NewDonutSeries
 aRet.push_back( aSeriesStyle );
 
 sal_Int32 nPointIndex=0;
-::std::vector< OUString >::iterator aPointIt( m_aPointStyles.begin() );
-::std::vector< OUString >::iterator aPointEnd( m_aPointStyles.end() );
-while( aPointIt != aPointEnd )
+for (auto const& pointStyle : m_aPointStyles)
 {
 DataRowPointStyle aPointStyle( DataRowPointStyle::DATA_POINT
-, m_xSeries, nPointIndex, 1, *aPointIt, mnAttachedAxis );
+, m_xSeries, nPointIndex, 1, pointStyle, mnAttachedAxis );
 if( nPointIndex < static_cast(m_aSeriesStyles.size()) )
 {
 aPointStyle.msSeriesStyleNameForDonuts = 
m_aSeriesStyles[nPointIndex];
@@ -494,7 +492,6 @@ struct NewDonutSeries
 if( !aPointStyle.msSeriesStyleNameForDonuts.isEmpty()
 || !aPointStyle.msStyleName.isEmpty() )
 aRet.push_back( aPointStyle );
-++aPointIt;
 ++nPointIndex;
 }
 
@@ -505,9 +502,6 @@ struct NewDonutSeries
 void lcl_swapPointAndSeriesStylesForDonutCharts( ::std::vector< 
DataRowPointStyle >& rStyleVector
 , const ::std::map< css::uno::Reference< css::chart2::XDataSeries> , 
sal_Int32 >& rSeriesMap )
 {
-::std::vector< DataRowPointStyle >::iterator aIt(rStyleVector.begin());
-::std::vector< DataRowPointStyle >::iterator aEnd(rStyleVector.end());
-
 //detect old series count
 //and add old series to aSeriesMap
 ::std::map< css::uno::Reference<
@@ -516,9 +510,9 @@ void lcl_swapPointAndSeriesStylesForDonutCharts( 
::std::vector< DataRowPointStyl
 {
 sal_Int32 nMaxOldSeriesIndex = 0;
 sal_Int32 nOldSeriesIndex = 0;
-for( aIt = rStyleVector.begin(); aIt != aEnd; ++aIt )
+for (auto const& style : rStyleVector)
 {
-DataRowPointStyle aStyle(*aIt);
+DataRowPointStyle aStyle(style);
 if(aStyle.meType == DataRowPointStyle::DATA_SERIES &&
 aStyle.m_xSeries.is() )
 {
@@ -534,62 +528,55 @@ void lcl_swapPointAndSeriesStylesForDonutCharts( 
::std::vector< DataRowPointStyl
 }
 
 //initialize new series styles
-::std::map< Reference< chart2::XDataSeries >, sal_Int32 >::const_iterator 
aSeriesMapIt( aSeriesMap.begin() );
 ::std::map< Reference< chart2::XDataSeries >, sal_Int32 >::const_iterator 
aSeriesMapEnd( aSeriesMap.end() );
 
 //sort by index
 ::std::vector< NewDonutSeries > aNewSeriesVector;
 {
 ::std::map< sal_Int32, Reference< chart2::XDataSeries > > 
aIndexSeriesMap;
-for( ; aSeriesMapIt != aSeriesMapEnd; ++aSeriesMapIt )
-aIndexSeriesMap[aSeriesMapIt->second] = aSeriesMapIt->first;
-
-::std::map< sal_Int32, Reference< chart2::XDataSeries > 
>::const_iterator aIndexIt( aIndexSeriesMap.begin() );
-::std::map< sal_Int32, Reference< chart2::XDataSeries > 
>::const_iterator aIndexEnd( aIndexSeriesMap.end() );
+for (auto const& series : aSeriesMap)
+aIndexSeriesMap[series.second] = series.first;
 
-for( ; aIndexIt != aIndexEnd; ++aIndexIt )
-aNewSeriesVector.emplace_back(aIndexIt->second,nOldSeriesCount );
+for (auto const& indexSeries : aIndexSeriesMap)
+aNewSeriesVector.emplace_back(indexSeries.second,nOldSeriesCount );
 }
 
 //overwrite attached axis information according to old series styles
-for( aIt = rStyleVector.begin(); aIt != aEnd; ++aIt )
+for (auto const& style : rStyleVector)
 {
-DataRowPointStyle aStyle(*aIt);
+DataRowPointStyle aStyle(style);
 if(aStyle.meType == DataRowPointStyle::DATA_SERIES )
 {
-aSeriesMapIt = aSeriesMap.find( aStyle.m_xSeries );
+auto aSeriesMapIt = aSeriesMap.find( aStyle.m_xSeries );
 if( aSeriesMapIt != aSeriesMapEnd && aSeriesMapIt->second < 
static_cast(aNewSeriesVector.size()) )
 aNewSeriesVector[aSeriesMapIt->second].mnAttachedAxis = 
aStyle.mnAttachedAxis;
 }
 }
 
 //overwrite new series style names with

Gergely Tarsoly license statement

2017-11-26 Thread Gergely Tarsoly
All of my past & future contributions to LibreOffice may be
   licensed under the MPLv2/LGPLv3+ dual license.___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] libvisio.git: src/lib

2017-11-26 Thread David Tardon
 src/lib/VSDXTheme.cpp |   15 +--
 src/lib/VSDXTheme.h   |4 ++--
 2 files changed, 11 insertions(+), 8 deletions(-)

New commits:
commit afa9437bec26a156aebdd60bc05fa48d68067629
Author: David Tardon 
Date:   Sun Nov 26 17:44:56 2017 +0100

ofz: ignore invalid/incomplete font entries

Change-Id: Ic5e6cf0afe62e92fba1503a1a3540eb50800dc3c

diff --git a/src/lib/VSDXTheme.cpp b/src/lib/VSDXTheme.cpp
index da69059..8db16e9 100644
--- a/src/lib/VSDXTheme.cpp
+++ b/src/lib/VSDXTheme.cpp
@@ -219,8 +219,8 @@ void libvisio::VSDXTheme::readFont(xmlTextReaderPtr reader, 
int idToken, VSDXFon
 {
   int script;
   librevenge::RVNGString typeFace;
-  readTypeFace(reader, script, typeFace);
-  font.m_typeFaces[script] = typeFace;
+  if (readTypeFace(reader, script, typeFace) && !typeFace.empty())
+font.m_typeFaces[script] = typeFace;
   break;
 }
 default:
@@ -230,7 +230,7 @@ void libvisio::VSDXTheme::readFont(xmlTextReaderPtr reader, 
int idToken, VSDXFon
   while ((idToken != tokenId || XML_READER_TYPE_END_ELEMENT != tokenType) && 1 
== ret);
 }
 
-void libvisio::VSDXTheme::readTypeFace(xmlTextReaderPtr reader, 
librevenge::RVNGString &typeFace)
+bool libvisio::VSDXTheme::readTypeFace(xmlTextReaderPtr reader, 
librevenge::RVNGString &typeFace)
 {
   const shared_ptr sTypeFace(xmlTextReaderGetAttribute(reader, 
BAD_CAST("typeface")), xmlFree);
   if (sTypeFace)
@@ -238,18 +238,21 @@ void libvisio::VSDXTheme::readTypeFace(xmlTextReaderPtr 
reader, librevenge::RVNG
 typeFace.clear();
 typeFace.sprintf("%s", (const char *)sTypeFace.get());
   }
+  return bool(sTypeFace);
 }
 
-void libvisio::VSDXTheme::readTypeFace(xmlTextReaderPtr reader, int &script, 
librevenge::RVNGString &typeFace)
+bool libvisio::VSDXTheme::readTypeFace(xmlTextReaderPtr reader, int &script, 
librevenge::RVNGString &typeFace)
 {
   const shared_ptr sScript(xmlTextReaderGetAttribute(reader, 
BAD_CAST("script")), xmlFree);
+  bool knownScript = false;
   if (sScript)
   {
 int token = libvisio::VSDXMLTokenMap::getTokenId(sScript.get());
-if (XML_TOKEN_INVALID != token)
+knownScript = XML_TOKEN_INVALID != token;
+if (knownScript)
   script = token;
   }
-  readTypeFace(reader, typeFace);
+  return readTypeFace(reader, typeFace) && knownScript;
 }
 
 void libvisio::VSDXTheme::readClrScheme(xmlTextReaderPtr reader)
diff --git a/src/lib/VSDXTheme.h b/src/lib/VSDXTheme.h
index e0de7c3..f600c96 100644
--- a/src/lib/VSDXTheme.h
+++ b/src/lib/VSDXTheme.h
@@ -94,8 +94,8 @@ private:
   void readVariationClrScheme(xmlTextReaderPtr reader, VSDXVariationClrScheme 
&varClrSch);
   void readFontScheme(xmlTextReaderPtr reader);
   void readFont(xmlTextReaderPtr reader, int idToken, VSDXFont &font);
-  void readTypeFace(xmlTextReaderPtr reader, librevenge::RVNGString &typeFace);
-  void readTypeFace(xmlTextReaderPtr reader, int &script, 
librevenge::RVNGString &typeFace);
+  bool readTypeFace(xmlTextReaderPtr reader, librevenge::RVNGString &typeFace);
+  bool readTypeFace(xmlTextReaderPtr reader, int &script, 
librevenge::RVNGString &typeFace);
 
   int getElementToken(xmlTextReaderPtr reader);
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: helpcompiler/inc helpcompiler/source

2017-11-26 Thread Julien Nabet
 helpcompiler/inc/BasCodeTagger.hxx|7 ---
 helpcompiler/inc/HelpCompiler.hxx |2 +-
 helpcompiler/source/BasCodeTagger.cxx |6 ++
 3 files changed, 7 insertions(+), 8 deletions(-)

New commits:
commit d8282c9adcd1c10b721bb72d6e4c8f993e862694
Author: Julien Nabet 
Date:   Sun Nov 26 16:41:00 2017 +0100

Replace lists by vector and deque (helpcompiler)

Change-Id: I8d65947f3188ab7b54653eee887de2c5d4f8095d
Reviewed-on: https://gerrit.libreoffice.org/45290
Tested-by: Jenkins 
Reviewed-by: Julien Nabet 

diff --git a/helpcompiler/inc/BasCodeTagger.hxx 
b/helpcompiler/inc/BasCodeTagger.hxx
index d8dbffa4cd49..7d485b166805 100644
--- a/helpcompiler/inc/BasCodeTagger.hxx
+++ b/helpcompiler/inc/BasCodeTagger.hxx
@@ -13,7 +13,8 @@
 #include 
 #include 
 #include 
-#include 
+#include 
+#include 
 #include 
 #include 
 #include 
@@ -28,7 +29,7 @@ class L10N_DLLPUBLIC BasicCodeTagger
 {
   private:
 xmlDocPtr m_pDocument;
-std::list m_BasicCodeContainerTags;
+std::vector m_BasicCodeContainerTags;
 LibXmlTreeWalker   *m_pXmlTreeWalker;
 SyntaxHighlighter m_Highlighter;
 bool m_bTaggingCompleted;
@@ -50,7 +51,7 @@ class L10N_DLLPUBLIC LibXmlTreeWalker
 {
   private:
 xmlNodePtrm_pCurrentNode;
-std::list m_Queue; //!Queue for breath-first search
+std::deque m_Queue; //!Queue for breath-first search
 
   public:
 LibXmlTreeWalker( xmlDocPtr doc );
diff --git a/helpcompiler/inc/HelpCompiler.hxx 
b/helpcompiler/inc/HelpCompiler.hxx
index 356f8dc5b64d..952e58acc987 100644
--- a/helpcompiler/inc/HelpCompiler.hxx
+++ b/helpcompiler/inc/HelpCompiler.hxx
@@ -152,7 +152,7 @@ struct joaat_hash
 #define pref_hash joaat_hash
 
 typedef std::unordered_map Stringtable;
-typedef std::list LinkedList;
+typedef std::deque LinkedList;
 typedef std::vector HashSet;
 
 typedef std::unordered_map Hashtable;
diff --git a/helpcompiler/source/BasCodeTagger.cxx 
b/helpcompiler/source/BasCodeTagger.cxx
index 20a4f1bb8061..215ea49996f6 100644
--- a/helpcompiler/source/BasCodeTagger.cxx
+++ b/helpcompiler/source/BasCodeTagger.cxx
@@ -103,19 +103,17 @@ void BasicCodeTagger::getBasicCodeContainerNodes()
 void BasicCodeTagger::tagBasCodeParagraphs()
 {
 //helper variables
-xmlNodePtr currBascodeNode;
 xmlNodePtr currParagraph;
-while ( !m_BasicCodeContainerTags.empty() )
+for (auto const& currBascodeNode : m_BasicCodeContainerTags)
 {
-currBascodeNode = m_BasicCodeContainerTags.front();
 currParagraph = currBascodeNode->xmlChildrenNode; //first 
 while ( currParagraph != nullptr )
 {
 tagParagraph( currParagraph );
 currParagraph=currParagraph->next;
 }
-m_BasicCodeContainerTags.pop_front(); //next element
 }
+m_BasicCodeContainerTags.clear();
 }
 
 //! Used by tagBasCodeParagraphs(). It does the work on the current paragraph 
containing Basic code.
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: xmloff/source

2017-11-26 Thread Julien Nabet
 xmloff/source/chart/SchXMLSeries2Context.cxx |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

New commits:
commit 5c2f6d9e2efe1015cfbf9d89a88ed940127c0a4f
Author: Julien Nabet 
Date:   Sun Nov 26 16:51:28 2017 +0100

No need to test seriesStyle.m_xOldAPISeries n times (xmloff/chart)

so move it out from the inner loop

Change-Id: I367dc428b10ff4554b63ee3cdabfe65ddfb61ea7
Reviewed-on: https://gerrit.libreoffice.org/45291
Tested-by: Jenkins 
Reviewed-by: Julien Nabet 

diff --git a/xmloff/source/chart/SchXMLSeries2Context.cxx 
b/xmloff/source/chart/SchXMLSeries2Context.cxx
index 82b6662771c6..01e9027caf95 100644
--- a/xmloff/source/chart/SchXMLSeries2Context.cxx
+++ b/xmloff/source/chart/SchXMLSeries2Context.cxx
@@ -1014,6 +1014,10 @@ void SchXMLSeries2Context::setStylesToDataPoints( 
SeriesDefaultsAndStyles& rSeri
 if( seriesStyle.m_nPointIndex == -1 )
 continue;
 
+uno::Reference< beans::XPropertySet > xSeriesProp( 
seriesStyle.m_xOldAPISeries );
+if(!xSeriesProp.is())
+continue;
+
 //ignore datapoint properties for stock charts
 //... todo ...
 if( bIsStockChart )
@@ -1027,10 +1031,6 @@ void SchXMLSeries2Context::setStylesToDataPoints( 
SeriesDefaultsAndStyles& rSeri
 {
 try
 {
-uno::Reference< beans::XPropertySet > xSeriesProp( 
seriesStyle.m_xOldAPISeries );
-if(!xSeriesProp.is())
-continue;
-
 uno::Reference< beans::XPropertySet > xPointProp(
 SchXMLSeriesHelper::createOldAPIDataPointPropertySet( 
seriesStyle.m_xSeries, seriesStyle.m_nPointIndex + i
 , uno::Reference< frame::XModel >( 
rImportHelper.GetChartDocument(), uno::UNO_QUERY ) ) );
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: configure.ac external/firebird external/libcmis ucb/source

2017-11-26 Thread Stephan Bergmann
 configure.ac   |   54 ++-
 external/firebird/UnpackedTarball_firebird.mk  |1 
 external/firebird/c++17.patch  |  301 ++
 external/libcmis/StaticLibrary_libcmis.mk  |   11 
 external/libcmis/UnpackedTarball_libcmis.mk|1 
 external/libcmis/c++17.patch.0 |  412 +
 ucb/source/ucp/cmis/auth_provider.hxx  |5 
 ucb/source/ucp/cmis/certvalidation_handler.hxx |5 
 ucb/source/ucp/cmis/cmis_content.hxx   |5 
 ucb/source/ucp/cmis/cmis_url.cxx   |5 
 10 files changed, 760 insertions(+), 40 deletions(-)

New commits:
commit ae16870b2c84c116cde8279a47db106a4fa9d529
Author: Stephan Bergmann 
Date:   Wed Oct 25 19:52:08 2017 +0200

Build as C++17 when GCC/Clang supports it

...and the gperf being used no longer emits "register" in C++ code.

Unlike Clang with -Wdynamic-exception-spec ignored, at least GCC 7.2
-std=gnu++17 always makes dynamic exception specs hard errors, which would 
cause
errors both when building StaticLibrary_libcmis and when including
libcmis/libcmis.hxx in ucb/source/ucp/cmis/.  So patch away all dynamic
exception specifications from all external/libcmis include files indirectly
included via libcmis/libcmis.hxx, and (to silence the remaining dynamic
exception specifications in the innards of external/libcmis, which I did not
feel like also patching away) build StaticLibrary_libcmis as C++03 if 
necessary,
and wait for upstream libcmis to eventually be ported to C++17.

And external/firebird needs to be built with CXXFLAGS_CXX11 (which amounts 
to
C++17 with this patch) since 9206a08ada00e8762c4a634f242bd566028964bb 
"Upgrade
to ICU 60.1", so the relevant dynamic exception specifications had to be 
patched
away from its innards.

Change-Id: I3a0c9ec83c7c1d413559459631970f69ab977f31
Reviewed-on: https://gerrit.libreoffice.org/43851
Tested-by: Jenkins 
Reviewed-by: Stephan Bergmann 

diff --git a/configure.ac b/configure.ac
index 42239059cdcd..3d0e09733ec5 100644
--- a/configure.ac
+++ b/configure.ac
@@ -5962,6 +5962,24 @@ AC_MSG_RESULT([$cpp_library_name])
 AC_LANG_POP([C++])
 
 dnl ===
+dnl Check for gperf
+dnl ===
+AC_PATH_PROG(GPERF, gperf)
+if test -z "$GPERF"; then
+AC_MSG_ERROR([gperf not found but needed. Install it.])
+fi
+if test "$GNUMAKE_WIN_NATIVE" = "TRUE" ; then
+GPERF=`cygpath -m $GPERF`
+fi
+AC_MSG_CHECKING([gperf version])
+if test "`$GPERF --version | $EGREP ^GNU\ gperf | $AWK '{ print $3 }' | cut 
-d. -f1`" -ge "3"; then
+AC_MSG_RESULT([OK])
+else
+AC_MSG_ERROR([too old, you need at least 3.0.0])
+fi
+AC_SUBST(GPERF)
+
+dnl ===
 dnl C++11
 dnl ===
 
@@ -5972,8 +5990,11 @@ if test "$COM" = MSC; then
 # MSVC supports (a subset of) CXX11 without any switch
 elif test "$GCC" = "yes"; then
 HAVE_CXX11=
-AC_MSG_CHECKING([whether $CXX supports C++14 or C++11])
-for flag in -std=gnu++14 -std=gnu++1y -std=c++14 -std=c++1y -std=gnu++11 
-std=gnu++0x -std=c++11 -std=c++0x ; do
+AC_MSG_CHECKING([whether $CXX supports C++17, C++14, or C++11])
+dnl But only use C++17 if the gperf that is being used knows not to emit
+dnl "register" in C++ output:
+printf 'foo\n' | $GPERF -L C++ > conftest.inc
+for flag in -std=gnu++17 -std=gnu++1z -std=c++17 -std=c++1z -std=gnu++14 
-std=gnu++1y -std=c++14 -std=c++1y -std=gnu++11 -std=gnu++0x -std=c++11 
-std=c++0x ; do
 save_CXXFLAGS=$CXXFLAGS
 CXXFLAGS="$CXXFLAGS $flag -Werror"
 AC_LANG_PUSH([C++])
@@ -5981,6 +6002,16 @@ elif test "$GCC" = "yes"; then
 #include 
 #include 
 #include 
+
+#include 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+// make GCC not warn about next pragma
+#pragma GCC diagnostic ignored "-Wdeprecated-register"
+// make Clang with -std < C++17 not even warn about register
+#include "conftest.inc"
+#pragma GCC diagnostic pop
+
 void f(std::vector & v, std::function fn) {
 std::sort(v.begin(), v.end(), fn);
 }
@@ -5992,6 +6023,7 @@ elif test "$GCC" = "yes"; then
 break
 fi
 done
+rm conftest.inc
 if test "$HAVE_CXX11" = TRUE; then
 AC_MSG_RESULT([yes ($CXXFLAGS_CXX11)])
 else
@@ -7262,24 +7294,6 @@ fi
 AC_SUBST(ENABLE_LWP)
 
 dnl ===
-dnl Check for gperf
-dnl ===
-AC_PATH_PROG(GPERF, gperf)

[Libreoffice-commits] core.git: configure.ac

2017-11-26 Thread Stephan Bergmann
 configure.ac |   17 -
 1 file changed, 17 deletions(-)

New commits:
commit 7e222aff21d82a818e3a0f72f7e4d7e2a83c7274
Author: Stephan Bergmann 
Date:   Fri Jun 16 15:49:07 2017 +0200

Remove dated configure check after LO 6.0 branch-off

See c127c19de62201b49b6647ef3ee8b08ae49da852 "Remove 
HAVE_CXX11_REF_QUALIFIER,
always true now".  By now, any outdated builders where this would fail 
should
have been identified and taken care of.

Change-Id: I5f823b48b40dd6a20991ebb118e077a0e88aacb1
Reviewed-on: https://gerrit.libreoffice.org/38887
Tested-by: Jenkins 
Reviewed-by: Stephan Bergmann 

diff --git a/configure.ac b/configure.ac
index 3d0e09733ec5..4ff7655c0f36 100644
--- a/configure.ac
+++ b/configure.ac
@@ -6172,23 +6172,6 @@ if test "$cxx14_constexpr" = yes; then
 AC_DEFINE([HAVE_CXX14_CONSTEXPR])
 fi
 
-AC_MSG_CHECKING([whether $CXX supports C++11 ref-qualifier])
-save_CXXFLAGS=$CXXFLAGS
-CXXFLAGS="$CXXFLAGS $CXXFLAGS_CXX11"
-AC_LANG_PUSH([C++])
-AC_COMPILE_IFELSE([AC_LANG_PROGRAM([[
-struct S {
-void f() &;
-void f() &&;
-};
-]])], [cxx11_ref_qualifier=yes], [cxx11_ref_qualifier=no])
-AC_LANG_POP([C++])
-CXXFLAGS=$save_CXXFLAGS
-AC_MSG_RESULT([$cxx11_ref_qualifier])
-if test "$cxx11_ref_qualifier" = no; then
-AC_MSG_ERROR([Your $CXX does not support C++11 ref-qualifiers. This is no 
longer supported.])
-fi
-
 dnl _Pragma support (may require C++11)
 if test "$GCC" = "yes" -o "$COM_IS_CLANG" = TRUE; then
 AC_MSG_CHECKING([whether $CXX supports _Pragma operator])
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: 2 commits - basic/Library_sb.mk ios/CustomTarget_iOS_prelink.mk ios/LibreOfficeLight ios/source

2017-11-26 Thread jan Iversen
 basic/Library_sb.mk |5 +-
 ios/CustomTarget_iOS_prelink.mk |   19 
--
 ios/LibreOfficeLight/LibreOfficeLight.xcodeproj/project.pbxproj |   19 
+++---
 ios/source/LibreOfficeKit.c |6 +++
 4 files changed, 30 insertions(+), 19 deletions(-)

New commits:
commit 1512b9fd5279277e7abd3ab232c9fd38e2cbfcf7
Author: jan Iversen 
Date:   Sun Nov 26 19:17:35 2017 +0100

basic, disable scripting problem

When building without scripting a couple of
functions were undeclared, to solve that
source/runtime/runtime
source/classes/sbintern
were moved so they also compile in building
without scripting

Change-Id: I908fee3caf8376d70ed286c17085d6b8a700ae75

diff --git a/basic/Library_sb.mk b/basic/Library_sb.mk
index f866a3bbd347..61424901e4e4 100644
--- a/basic/Library_sb.mk
+++ b/basic/Library_sb.mk
@@ -71,7 +71,6 @@ $(eval $(call gb_Library_add_exception_objects,sb,\
basic/source/classes/image \
basic/source/classes/propacc \
basic/source/classes/sb \
-   basic/source/classes/sbintern \
basic/source/classes/sbunoobj \
basic/source/classes/sbxmod \
basic/source/comp/basiccharclass \
@@ -97,17 +96,17 @@ $(eval $(call gb_Library_add_exception_objects,sb,\
basic/source/runtime/inputbox \
basic/source/runtime/iosys \
basic/source/runtime/props \
-   basic/source/runtime/runtime \
basic/source/runtime/stdobj \
basic/source/runtime/stdobj1 \
 ))
-
 endif
 
 $(eval $(call gb_Library_add_exception_objects,sb,\
basic/source/runtime/basrdll \
basic/source/runtime/methods \
basic/source/runtime/methods1 \
+   basic/source/runtime/runtime \
+   basic/source/classes/sbintern \
basic/source/sbx/sbxarray \
basic/source/sbx/sbxbool \
basic/source/sbx/sbxbyte \
commit 781c532068e4b51a372b149ee2b8f48a1c10e79f
Author: jan Iversen 
Date:   Sun Nov 26 12:23:45 2017 +0100

iOS, make Kit symbols external

Xcode has a problem (a bug) with linkink .o files to a
project, this is ignored on the linker line.

We use visisbility=hidden as default, therefore the symbols
to be exported need to have the attribute
visibility=default

Change-Id: I079189dbaf6c0f606028a1e582f320db97995285

diff --git a/ios/CustomTarget_iOS_prelink.mk b/ios/CustomTarget_iOS_prelink.mk
index 2588e72110ca..2670f9449b6e 100644
--- a/ios/CustomTarget_iOS_prelink.mk
+++ b/ios/CustomTarget_iOS_prelink.mk
@@ -8,11 +8,12 @@
 #- Env 
 IOSDEV = /Applications/Xcode.app/Contents/Developer/
 IOSLD = $(IOSDEV)Toolchains/XcodeDefault.xctoolchain/usr/bin/ld
+IOSOBJ = $(WORKDIR)/ios/Kit.o
 
 ifeq ($(ENABLE_DEBUG),TRUE)
-IOSKIT = $(SRCDIR)/ios/generated/LibreOfficeKit_$(CPUNAME)_debug.o
+IOSKIT = $(SRCDIR)/ios/generated/libKit_$(CPUNAME)_debug.a
 else
-IOSKIT = $(SRCDIR)/ios/generated/LibreOfficeKit_$(CPUNAME).o
+IOSKIT = $(SRCDIR)/ios/generated/libKit_$(CPUNAME).a
 endif
 
 
@@ -32,15 +33,11 @@ $(IOSKIT): $(call 
gb_StaticLibrary_get_target,iOS_kitBridge) FORCE
$(IOSLD) -r -ios_version_min 11.1 \
-syslibroot $(MACOSX_SDK_PATH) \
-arch `echo $(CPUNAME) |  tr '[:upper:]' '[:lower:]'` \
-   -o $(IOSKIT) \
-   $(WORKDIR)/CObject/ios/source/LibreOfficeKit.o  \
-   `$(SRCDIR)/bin/lo-all-static-libs`
-
-
-
-# prelink parms: -ios_version_min 11.0 -lz -liconv -g -Wl
-#  -e "s'@SYMROOT@'$(WORKDIR)/ios/build'g" \
-#  -sdk $(IOS_SDK) \
+   -o $(IOSOBJ) \
+   $(WORKDIR)/CObject/ios/source/LibreOfficeKit.o \
+   `$(SRCDIR)/bin/lo-all-static-libs` \
+   $(call gb_StaticLibrary_get_target,iOS_kitBridge)
+   $(AR) -r $(IOSKIT) $(IOSOBJ)
 
 
 
diff --git a/ios/LibreOfficeLight/LibreOfficeLight.xcodeproj/project.pbxproj 
b/ios/LibreOfficeLight/LibreOfficeLight.xcodeproj/project.pbxproj
index becd7212d156..2b9d95f4eb48 100644
--- a/ios/LibreOfficeLight/LibreOfficeLight.xcodeproj/project.pbxproj
+++ b/ios/LibreOfficeLight/LibreOfficeLight.xcodeproj/project.pbxproj
@@ -16,7 +16,7 @@
393975781F8BECB0002DC80B /* libiconv.tbd in Frameworks */ = 
{isa = PBXBuildFile; fileRef = 393975771F8BECB0002DC80B /* libiconv.tbd */; };
3939757A1F8BECC1002DC80B /* libz.tbd in Frameworks */ = {isa = 
PBXBuildFile; fileRef = 393975791F8BECC1002DC80B /* libz.tbd */; };
39503A751F94D44900F19C78 /* libc++.tbd in Frameworks */ = {isa 
= PBXBuildFile; fileRef = 39503A741F94D44900F19C78 /* libc++.tbd */; };
-   396C83371FC989AB008E662A /* dummyLOkit.c in Sources */ = {isa = 
PBXBuildFile; fileRef = 39284DB01FA5E150006F43E4 /* dummyLOkit.c */; };
+   396C833F1FC9D89E008E662A /* libKit_X86_64_debug.a in Frameworks 
*/ = {isa =

[Libreoffice-commits] core.git: filter/source

2017-11-26 Thread Chr . Rossmanith
 filter/source/svg/svgwriter.cxx |   22 --
 1 file changed, 8 insertions(+), 14 deletions(-)

New commits:
commit c4c4c7e37462eddb3da0b9150a7edfdccfb0aa55
Author: Chr. Rossmanith 
Date:   Wed Nov 22 22:30:00 2017 +0100

svg export: more compact format for rotate()

translate(, ) rotate() translate(-, -) can
be expressed more compact as rotate(  )

Change-Id: I156cc8b43eea8c97167c8ae38b367d1bcbb203bd
Reviewed-on: https://gerrit.libreoffice.org/45146
Tested-by: Jenkins 
Reviewed-by: Christina Roßmanith 

diff --git a/filter/source/svg/svgwriter.cxx b/filter/source/svg/svgwriter.cxx
index 824f21be6ccd..83f4e8ec2580 100644
--- a/filter/source/svg/svgwriter.cxx
+++ b/filter/source/svg/svgwriter.cxx
@@ -1228,13 +1228,10 @@ void SVGTextWriter::startTextShape()
 if( rFont.GetOrientation() )
 {
 Point   aRot( maTextPos );
-OUString aTransform =
-"translate(" + OUString::number( aRot.X() ) +
-"," + OUString::number( aRot.Y() ) + ") rotate(" +
-OUString::number( rFont.GetOrientation() * -0.1 ) +
-") translate(" + OUString::number( -aRot.X() ) +
-"," + OUString::number( -aRot.Y() ) + ")";
-
+OUString aTransform = "rotate(" +
+OUString::number( rFont.GetOrientation() * -0.1 ) + " " +
+OUString::number( aRot.X() ) + " " +
+OUString::number( aRot.Y() ) + ")";
 mrExport.AddAttribute( XML_NAMESPACE_NONE, aXMLAttrTransform, 
aTransform );
 }
 
@@ -2568,13 +2565,10 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, 
const OUString& rText,
 if( rFont.GetOrientation() )
 {
 Point   aRot( aPos );
-OUString  aTransform =
-"translate(" + OUString::number( aRot.X() ) +
-"," + OUString::number( aRot.Y() ) + ") rotate(" +
-OUString::number( rFont.GetOrientation() * -0.1 ) +
-") translate(" + OUString::number( -aRot.X() ) +
-"," + OUString::number( -aRot.Y() ) + ")";
-
+OUString  aTransform = "rotate(" +
+OUString::number( rFont.GetOrientation() * -0.1 ) + " " +
+OUString::number( aRot.X() ) + " " +
+OUString::number( aRot.Y() ) + ")";
 mrExport.AddAttribute( XML_NAMESPACE_NONE, aXMLAttrTransform, 
aTransform );
 }
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sdext/source sd/inc sd/source

2017-11-26 Thread Jochen Nitschke
 sd/inc/OutlinerIterator.hxx |7 ---
 sd/inc/drawdoc.hxx  |1 
 sd/source/core/drawdoc.cxx  |   17 ---
 sd/source/ui/sidebar/MasterPageDescriptor.cxx   |   23 
--
 sd/source/ui/sidebar/MasterPageDescriptor.hxx   |2 
 sd/source/ui/slidesorter/inc/controller/SlsTransferableData.hxx |6 --
 sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx   |1 
 sd/source/ui/slidesorter/view/SlsLayouter.cxx   |   17 ---
 sd/source/ui/view/OutlinerIterator.cxx  |9 ---
 sd/source/ui/view/ViewShellManager.cxx  |   22 
-
 sdext/source/pdfimport/sax/saxattrlist.cxx  |   11 
 sdext/source/pdfimport/sax/saxattrlist.hxx  |2 
 12 files changed, 118 deletions(-)

New commits:
commit e641975076db46381f39ebca82bd43c503c3880c
Author: Jochen Nitschke 
Date:   Sun Nov 26 17:27:45 2017 +0100

clang-tidy modernize-use-equals-default in sd

Change-Id: Ib3d3bb1a0484cb8bb6411444254644252e3614cf
Reviewed-on: https://gerrit.libreoffice.org/45293
Tested-by: Jenkins 
Reviewed-by: Noel Grandin 

diff --git a/sd/inc/OutlinerIterator.hxx b/sd/inc/OutlinerIterator.hxx
index d61448db7c91..0696fbffc265 100644
--- a/sd/inc/OutlinerIterator.hxx
+++ b/sd/inc/OutlinerIterator.hxx
@@ -288,13 +288,6 @@ public:
 it is as a marker in comparisons.
 */
 IteratorPosition();
-/** Create a new object with all data members set from the given
-position.
-@param aPosition
-The position object from which to take the values that are
-assigned to the data members of this object.
-*/
-IteratorPosition (const IteratorPosition& aPosition);
 
 /** Compare two positions for equality.
 @return
diff --git a/sd/inc/drawdoc.hxx b/sd/inc/drawdoc.hxx
index 2ce8fabb9de4..8a0af1398287 100644
--- a/sd/inc/drawdoc.hxx
+++ b/sd/inc/drawdoc.hxx
@@ -126,7 +126,6 @@ namespace sd
 bool mbShowPauseLogo;
 
 PresentationSettings();
-PresentationSettings( const PresentationSettings& r );
 };
 }
 
diff --git a/sd/source/core/drawdoc.cxx b/sd/source/core/drawdoc.cxx
index ff30462fc3c9..620607507790 100644
--- a/sd/source/core/drawdoc.cxx
+++ b/sd/source/core/drawdoc.cxx
@@ -130,23 +130,6 @@ PresentationSettings::PresentationSettings()
 {
 }
 
-PresentationSettings::PresentationSettings( const PresentationSettings& r )
-:   maPresPage( r.maPresPage ),
-mbAll( r.mbAll ),
-mbEndless( r.mbEndless ),
-mbCustomShow( r.mbCustomShow ),
-mbManual( r.mbManual ),
-mbMouseVisible( r.mbMouseVisible ),
-mbMouseAsPen( r.mbMouseAsPen ),
-mbLockedPages( r.mbLockedPages ),
-mbAlwaysOnTop( r.mbAlwaysOnTop ),
-mbFullScreen( r.mbFullScreen ),
-mbAnimationAllowed( r.mbAnimationAllowed ),
-mnPauseTimeout( r.mnPauseTimeout ),
-mbShowPauseLogo( r.mbShowPauseLogo )
-{
-}
-
 SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
 : FmFormModel( !utl::ConfigManager::IsFuzzing() ? 
SvtPathOptions().GetPalettePath() : OUString(), nullptr, pDrDocSh )
 , mpOutliner(nullptr)
diff --git a/sd/source/ui/sidebar/MasterPageDescriptor.cxx 
b/sd/source/ui/sidebar/MasterPageDescriptor.cxx
index 26e44eff0f7e..87a27d597870 100644
--- a/sd/source/ui/sidebar/MasterPageDescriptor.cxx
+++ b/sd/source/ui/sidebar/MasterPageDescriptor.cxx
@@ -55,29 +55,6 @@ MasterPageDescriptor::MasterPageDescriptor (
 {
 }
 
-MasterPageDescriptor::MasterPageDescriptor (const MasterPageDescriptor& 
rDescriptor)
-: maToken(rDescriptor.maToken),
-  meOrigin(rDescriptor.meOrigin),
-  msURL(rDescriptor.msURL),
-  msPageName(rDescriptor.msPageName),
-  msStyleName(rDescriptor.msStyleName),
-  mbIsPrecious(rDescriptor.mbIsPrecious),
-  mpMasterPage(rDescriptor.mpMasterPage),
-  mpSlide(rDescriptor.mpSlide),
-  maSmallPreview(rDescriptor.maSmallPreview),
-  maLargePreview(rDescriptor.maLargePreview),
-  mpPreviewProvider(rDescriptor.mpPreviewProvider),
-  mpPageObjectProvider(rDescriptor.mpPageObjectProvider),
-  mnTemplateIndex(rDescriptor.mnTemplateIndex),
-  meURLClassification(rDescriptor.meURLClassification),
-  mnUseCount(rDescriptor.mnUseCount)
-{
-}
-
-MasterPageDescriptor::~MasterPageDescriptor()
-{
-}
-
 void MasterPageDescriptor::SetToken (MasterPageContainer::Token aToken)
 {
 maToken = aToken;
diff --git a/sd/source/ui/sidebar/MasterPageDescriptor.hxx 
b/sd/source/ui/sidebar/MasterPageDescriptor.hxx
index d4bb8cc40def..dfc7795189b5 100644
--- a/sd/source/ui/sidebar/MasterPageDescriptor.hxx
+++ b/sd/source/ui/sidebar/MasterPageDescriptor.hxx
@@ -46,8 +46,6 @@ public:
 const bool bIsPrecious,
 const std::shared_ptr& rpPageObjectProvider,
 const std::shared_ptr& rpP

[Libreoffice-commits] core.git: filter/source

2017-11-26 Thread Caolán McNamara
 filter/source/msfilter/msdffimp.cxx |   24 
 1 file changed, 16 insertions(+), 8 deletions(-)

New commits:
commit fc8e7168b5d991d10dc556b5bf90efaa5d9c949e
Author: Caolán McNamara 
Date:   Sun Nov 26 13:18:04 2017 +

ofz#4435 Bad-cast

Change-Id: Ie0364c758af84097cee93e4f6c5e8af2816359d4
Reviewed-on: https://gerrit.libreoffice.org/45285
Tested-by: Jenkins 
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 

diff --git a/filter/source/msfilter/msdffimp.cxx 
b/filter/source/msfilter/msdffimp.cxx
index eac8803da7f4..9c3a8f6a10ee 100644
--- a/filter/source/msfilter/msdffimp.cxx
+++ b/filter/source/msfilter/msdffimp.cxx
@@ -4100,11 +4100,15 @@ SdrObject* SvxMSDffManager::ImportGroup( const 
DffRecordHeader& rHd, SvStream& r
 return pRet;
 sal_Int32 nShapeId;
 SdrObject* pTmp = ImportGroup( aRecHd2, rSt, pClientData, 
aGroupClientAnchor, aGroupChildAnchor, nCalledByGroup + 1, &nShapeId );
-if ( pTmp && pRet && 
static_cast(pRet)->GetSubList() )
+if (pTmp)
 {
-
static_cast(pRet)->GetSubList()->NbcInsertObject( pTmp );
-if( nShapeId )
-insertShapeId( nShapeId, pTmp );
+SdrObjGroup* pGroup = dynamic_cast(pRet);
+if (pGroup && pGroup->GetSubList())
+{
+pGroup->GetSubList()->NbcInsertObject(pTmp);
+if (nShapeId)
+insertShapeId(nShapeId, pTmp);
+}
 }
 }
 else if ( aRecHd2.nRecType == DFF_msofbtSpContainer )
@@ -4113,11 +4117,15 @@ SdrObject* SvxMSDffManager::ImportGroup( const 
DffRecordHeader& rHd, SvStream& r
 return pRet;
 sal_Int32 nShapeId;
 SdrObject* pTmp = ImportShape( aRecHd2, rSt, pClientData, 
aClientRect, aGlobalChildRect, nCalledByGroup + 1, &nShapeId );
-if ( pTmp && pRet && 
static_cast(pRet)->GetSubList())
+if (pTmp)
 {
-
static_cast(pRet)->GetSubList()->NbcInsertObject( pTmp );
-if( nShapeId )
-insertShapeId( nShapeId, pTmp );
+SdrObjGroup* pGroup = dynamic_cast(pRet);
+if (pGroup && pGroup->GetSubList())
+{
+pGroup->GetSubList()->NbcInsertObject(pTmp);
+if (nShapeId)
+insertShapeId(nShapeId, pTmp);
+}
 }
 }
 if (!aRecHd2.SeekToEndOfRecord(rSt))
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: filter/source sd/source

2017-11-26 Thread Caolán McNamara
 filter/source/msfilter/msdffimp.cxx |5 -
 sd/source/filter/ppt/pptin.cxx  |2 +-
 2 files changed, 5 insertions(+), 2 deletions(-)

New commits:
commit f35a63deeb85a93f082eaebbfc6f1130d8729275
Author: Caolán McNamara 
Date:   Sun Nov 26 20:45:10 2017 +

ofz#4436 check if seek succeeded

Change-Id: I56d9692647b28c706b56ccacf08d494b3d830d94
Reviewed-on: https://gerrit.libreoffice.org/45294
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 

diff --git a/filter/source/msfilter/msdffimp.cxx 
b/filter/source/msfilter/msdffimp.cxx
index 9c3a8f6a10ee..c2f77d7beb2b 100644
--- a/filter/source/msfilter/msdffimp.cxx
+++ b/filter/source/msfilter/msdffimp.cxx
@@ -6039,7 +6039,10 @@ bool SvxMSDffManager::GetShapeGroupContainerData( 
SvStream& rSt,
 return false;
 }
 else
-rSt.SeekRel( nLength );
+{
+if (!checkSeek(rSt, rSt.Tell() + nLength))
+return false;
+}
 nReadSpGrCont += nLength;
 }
 while( nReadSpGrCont < nLenShapeGroupCont );
diff --git a/sd/source/filter/ppt/pptin.cxx b/sd/source/filter/ppt/pptin.cxx
index 60eb678303b0..4215cd7b60a8 100644
--- a/sd/source/filter/ppt/pptin.cxx
+++ b/sd/source/filter/ppt/pptin.cxx
@@ -857,7 +857,7 @@ bool ImplSdPPTImport::Import()
 bool bSuccess = aHd.SeekToEndOfRecord(rStCtrl);
 if (!bSuccess)
 {
-SAL_WARN("filter.ms", "Count not seek to end of 
record");
+SAL_WARN("filter.ms", "Could not seek to end of 
record");
 break;
 }
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: drawinglayer/source include/drawinglayer

2017-11-26 Thread Caolán McNamara
 drawinglayer/source/primitive2d/textlayoutdevice.cxx  |2 +-
 include/drawinglayer/primitive2d/textlayoutdevice.hxx |2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

New commits:
commit b5f0395aa408e831f4cc6182c65885ee2a78f90e
Author: Caolán McNamara 
Date:   Sun Nov 26 21:12:20 2017 +

coverity#1421100 Uncaught exception

Change-Id: Id9cb50e0e3eace3365eefe29650e993694480d47

diff --git a/drawinglayer/source/primitive2d/textlayoutdevice.cxx 
b/drawinglayer/source/primitive2d/textlayoutdevice.cxx
index 3b49ad6c13e5..ca0b8bb7e95c 100644
--- a/drawinglayer/source/primitive2d/textlayoutdevice.cxx
+++ b/drawinglayer/source/primitive2d/textlayoutdevice.cxx
@@ -157,7 +157,7 @@ namespace drawinglayer
 {
 }
 
-TextLayouterDevice::~TextLayouterDevice()
+TextLayouterDevice::~TextLayouterDevice() COVERITY_NOEXCEPT_FALSE
 {
 releaseGlobalVirtualDevice();
 }
diff --git a/include/drawinglayer/primitive2d/textlayoutdevice.hxx 
b/include/drawinglayer/primitive2d/textlayoutdevice.hxx
index c8670603e26a..478c630f311f 100644
--- a/include/drawinglayer/primitive2d/textlayoutdevice.hxx
+++ b/include/drawinglayer/primitive2d/textlayoutdevice.hxx
@@ -64,7 +64,7 @@ namespace drawinglayer
 public:
 /// constructor/destructor
 TextLayouterDevice();
-~TextLayouterDevice();
+~TextLayouterDevice() COVERITY_NOEXCEPT_FALSE;
 
 /// tooling methods
 void setFont(const vcl::Font& rFont);
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sd/source

2017-11-26 Thread Caolán McNamara
 sd/source/ui/slidesorter/controller/SlsFocusManager.cxx |2 +-
 sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx |2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 0217afae8f2ff48f9a746a90e8b937bb5c1864a9
Author: Caolán McNamara 
Date:   Sun Nov 26 21:15:52 2017 +

coverity#1421097 Uncaught exception

Change-Id: I503ca4ca71727a96f656a2dec97d7c202edfd806

diff --git a/sd/source/ui/slidesorter/controller/SlsFocusManager.cxx 
b/sd/source/ui/slidesorter/controller/SlsFocusManager.cxx
index fa8af54a284a..c39a56908c1a 100644
--- a/sd/source/ui/slidesorter/controller/SlsFocusManager.cxx
+++ b/sd/source/ui/slidesorter/controller/SlsFocusManager.cxx
@@ -235,7 +235,7 @@ FocusManager::FocusHider::FocusHider (FocusManager& 
rManager)
 mrManager.HideFocus();
 }
 
-FocusManager::FocusHider::~FocusHider()
+FocusManager::FocusHider::~FocusHider() COVERITY_NOEXCEPT_FALSE
 {
 if (mbFocusVisible)
 mrManager.ShowFocus();
diff --git a/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx 
b/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx
index 4801d80956ab..7fc7d3483223 100644
--- a/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx
+++ b/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx
@@ -158,7 +158,7 @@ public:
 {
 public:
 FocusHider (FocusManager&);
-~FocusHider();
+~FocusHider() COVERITY_NOEXCEPT_FALSE;
 private:
 bool mbFocusVisible;
 FocusManager& mrManager;
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sd/source

2017-11-26 Thread Caolán McNamara
 sd/source/ui/inc/ViewShellImplementation.hxx  |2 +-
 sd/source/ui/view/ViewShellImplementation.cxx |2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

New commits:
commit d1403852e5d31a3d22b644137a03f5188a103b20
Author: Caolán McNamara 
Date:   Sun Nov 26 21:26:10 2017 +

coverity#1421087 Uncaught exception

Change-Id: Ib00d20580178c80f653e26d5d23f81f4e81d2210

diff --git a/sd/source/ui/inc/ViewShellImplementation.hxx 
b/sd/source/ui/inc/ViewShellImplementation.hxx
index 65222ff5fe5f..294d648ad0d4 100644
--- a/sd/source/ui/inc/ViewShellImplementation.hxx
+++ b/sd/source/ui/inc/ViewShellImplementation.hxx
@@ -96,7 +96,7 @@ public:
 std::weak_ptr mpUpdateLockForMouse;
 
 Implementation (ViewShell& rViewShell);
-~Implementation();
+~Implementation() COVERITY_NOEXCEPT_FALSE;
 
 /** Process the SID_MODIFY slot.
 */
diff --git a/sd/source/ui/view/ViewShellImplementation.cxx 
b/sd/source/ui/view/ViewShellImplementation.cxx
index f625b9a7a1af..9ad12b4639b3 100644
--- a/sd/source/ui/view/ViewShellImplementation.cxx
+++ b/sd/source/ui/view/ViewShellImplementation.cxx
@@ -70,7 +70,7 @@ ViewShell::Implementation::Implementation (ViewShell& 
rViewShell)
 {
 }
 
-ViewShell::Implementation::~Implementation()
+ViewShell::Implementation::~Implementation() COVERITY_NOEXCEPT_FALSE
 {
 if ( ! mpUpdateLockForMouse.expired())
 {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: reportdesign/source

2017-11-26 Thread Caolán McNamara
 reportdesign/source/ui/inc/dlgedfac.hxx|2 +-
 reportdesign/source/ui/report/dlgedfac.cxx |2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 8c99d76144b550b17810135418d1c2f12ef8f138
Author: Caolán McNamara 
Date:   Sun Nov 26 21:31:06 2017 +

coverity#1421074 Uncaught exception

Change-Id: Id3decb150cfa2d994208c79f9d015d21d351f987

diff --git a/reportdesign/source/ui/inc/dlgedfac.hxx 
b/reportdesign/source/ui/inc/dlgedfac.hxx
index a75315fdd3df..f35d657575d6 100644
--- a/reportdesign/source/ui/inc/dlgedfac.hxx
+++ b/reportdesign/source/ui/inc/dlgedfac.hxx
@@ -33,7 +33,7 @@ class DlgEdFactory
 {
 public:
 DlgEdFactory();
-~DlgEdFactory();
+~DlgEdFactory() COVERITY_NOEXCEPT_FALSE;
 
 DECL_STATIC_LINK( DlgEdFactory, MakeObject, SdrObjCreatorParams, 
SdrObject* );
 };
diff --git a/reportdesign/source/ui/report/dlgedfac.cxx 
b/reportdesign/source/ui/report/dlgedfac.cxx
index 823e2b315685..1a59852f1029 100644
--- a/reportdesign/source/ui/report/dlgedfac.cxx
+++ b/reportdesign/source/ui/report/dlgedfac.cxx
@@ -37,7 +37,7 @@ DlgEdFactory::DlgEdFactory()
 }
 
 
-DlgEdFactory::~DlgEdFactory()
+DlgEdFactory::~DlgEdFactory() COVERITY_NOEXCEPT_FALSE
 {
 SdrObjFactory::RemoveMakeObjectHdl( LINK(this, DlgEdFactory, MakeObject) );
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Re: Need code pointer for import of attributes

2017-11-26 Thread Regina Henschel

Hi Michael,

Michael Stahl schrieb am 23.11.2017 um 21:37:

On 22.11.2017 17:32, Regina Henschel wrote:

Hi all,

I've started on
https://bugs.documentfoundation.org/show_bug.cgi?id=101242. My current
work is in the attachment.

Problem: Although I remove the config-items IsVisible, IsPrintable,
IsLocked from the settings.xml of a file, the values from draw:display
and draw:locked of the  element are not used. It seems to
me, that somewhere the read values are overwritten with a default.

Where and when are the values from settings.xml transformed to
properties of the layers of a newly opened draw document?


probably in sd/source/ui/view/frmview.cxx,
FrameView::ReadUserDataSequence(), around line 858


There the values from settings.xml are indeed read, but it sets no 
defaults. If the node does not exists, nothing is changed.





Any other hint, where to look?


there are SetVisibleLayers functions on 3 different classes, maybe
setting breakpoints on those would be helpful.


"setting breakpoints" was a good tip.

I use VS2017 and there is no "vs2017-ide-integration" yet. But I have 
tried the "vs2015-ide-integration" and it seems to work :)


I looked a little bit around for SetVisibleLayers and SdrLayerIDSet 
without success.


Then I started from the other end and looked what happens with my not 
working
xLayer->setPropertyValue("IsLocked",(msbProtected == "true") ? Any(true) 
: Any(false) );

compared to the working
xLayer->setPropertyValue("Title", Any( sTitleBuffer.makeStringAndClear() 
) );


I found this:
setPropertyValue is a method of class SdLayer [in 
sd\source\ui\unoidl\unolayer.hxx]


The SdLayer itself has no members to store the information. In case of 
"Title" the SdrLayer is used, for which the SdLayer has a pointer. This 
SdrLayer has the member maTitle to take the information. It has no 
members to take IsLocked, IsVisible or IsPrintable.


In case of "IsLocked" the SdLayer uses its member mxLayerManager to get 
a View of a page or a FrameView of the DocShell. But both doesn't exists 
at this stage, when loading a document. So the call of set(...) returns 
false; the source has the comment "//TODO: uno::Exception?"


The result is, that the information is not overwritten as I first 
thought, but is simple lost.


A  can have its own . But the 
 to be used for the page can also be inherited from a 
master page via  or . Therefore 
a solution is needed, which can be extended to support all three places.


As you know, currently the IsLocked/IsVisible/IsPrintable is not stored 
in the document itself, but in the settings.xml, despite the fact, that 
ODF can express the information. [Remember ODF TC discussion on 
OFFICE-3693 to not use settings.xml in those cases.]


New members mbIsLocked, mbIsVisible and mbIsPrintable for the SdrLayer 
would likely work [not worked out yet] as long as the layer settings are 
unique throughout the document, but they need not be unique in ODF.


So what to do?

Kind regard
Regina

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: sw/uiconfig

2017-11-26 Thread andreas kainz
 sw/uiconfig/swriter/ui/notebookbar_groupedbar_compact.ui |  181 +--
 1 file changed, 117 insertions(+), 64 deletions(-)

New commits:
commit 76a0e3830031cb7b3513c14d0209c7a24a98c65d
Author: andreas kainz 
Date:   Sun Nov 26 23:42:22 2017 +0100

Groupedbar compact add PriorityMergedHBox and OptionalBox

Change-Id: I560213b77161db68244c47400d4e1bbd29e68e37
Reviewed-on: https://gerrit.libreoffice.org/45299
Reviewed-by: andreas_kainz 
Tested-by: andreas_kainz 

diff --git a/sw/uiconfig/swriter/ui/notebookbar_groupedbar_compact.ui 
b/sw/uiconfig/swriter/ui/notebookbar_groupedbar_compact.ui
index d25830d46375..d72695a82334 100644
--- a/sw/uiconfig/swriter/ui/notebookbar_groupedbar_compact.ui
+++ b/sw/uiconfig/swriter/ui/notebookbar_groupedbar_compact.ui
@@ -2,6 +2,7 @@
 
 
   
+  
   
   
 True
@@ -4385,7 +4386,6 @@
   
 True
 False
-bottom
 
   
 True
@@ -4518,7 +4518,6 @@
   
 True
 False
-bottom
 
   
 True
@@ -4714,9 +4713,6 @@
 1
   
 
-
-  
-
   
   
 False
@@ -4728,7 +4724,6 @@
   
 True
 False
-bottom
 
   
 True
@@ -4959,7 +4954,6 @@
   
 True
 False
-bottom
 
   
 True
@@ -5111,7 +5105,6 @@
   
 True
 False
-bottom
 
   
 True
@@ -5225,7 +5218,6 @@
   
 True
 False
-bottom
 
   
 True
@@ -5339,7 +5331,6 @@
   
 True
 False
-bottom
 
   
 True
@@ -5458,10 +5449,10 @@
   
 
 
-  
+  
 False
 
-  
+  
 True
 False
 bottom
@@ -5579,6 +5570,9 @@
 1
   
 
+
+  
+
   
   
 False
@@ -5587,7 +5581,7 @@
   
 
 
-  
+  
 True
 False
 bottom
@@ -5794,7 +5788,7 @@
   
 
 
-  
+  
 True
 False
 bottom
@@ -5946,6 +5940,9 @@
 1
   
 
+
+  
+
   
   
 False
@@ -5954,7 +5951,7 @@
   
 
 
-  
+  
 True
 False
 bottom
@@ -6082,6 +6079,9 @@
 1
   
 
+
+  
+
   
   
 False
@@ -6090,7 +6090,7 @@
   
 
 
-  
+  
 True
 False
 bottom
@@ -6192,6 +6192,9 @@
 1
   
 
+
+  

[Libreoffice-commits] core.git: icon-themes/elementary

2017-11-26 Thread andreas kainz
 icon-themes/elementary/cmd/lc_downsearch.png|binary
 icon-themes/elementary/cmd/lc_downsearch.svg|   53 +
 icon-themes/elementary/cmd/lc_firstrecord.png   |binary
 icon-themes/elementary/cmd/lc_firstrecord.svg   |   67 +-
 icon-themes/elementary/cmd/lc_lastrecord.png|binary
 icon-themes/elementary/cmd/lc_lastrecord.svg|   56 +-
 icon-themes/elementary/cmd/lc_movedown.png  |binary
 icon-themes/elementary/cmd/lc_movedown.svg  |   53 +
 icon-themes/elementary/cmd/lc_movedownsubitems.png  |binary
 icon-themes/elementary/cmd/lc_movedownsubitems.svg  |   73 ++
 icon-themes/elementary/cmd/lc_movepagedown.png  |binary
 icon-themes/elementary/cmd/lc_movepagedown.svg  |   53 +
 icon-themes/elementary/cmd/lc_movepagefirst.png |binary
 icon-themes/elementary/cmd/lc_movepagefirst.svg |   67 +-
 icon-themes/elementary/cmd/lc_movepagelast.png  |binary
 icon-themes/elementary/cmd/lc_movepagelast.svg  |   56 +-
 icon-themes/elementary/cmd/lc_movepageup.png|binary
 icon-themes/elementary/cmd/lc_movepageup.svg|   47 +
 icon-themes/elementary/cmd/lc_moveup.png|binary
 icon-themes/elementary/cmd/lc_moveup.svg|   47 +
 icon-themes/elementary/cmd/lc_moveupsubitems.png|binary
 icon-themes/elementary/cmd/lc_moveupsubitems.svg|  103 ++-
 icon-themes/elementary/cmd/lc_nextrecord.png|binary
 icon-themes/elementary/cmd/lc_nextrecord.svg|   45 +
 icon-themes/elementary/cmd/lc_nexttrackedchange.png |binary
 icon-themes/elementary/cmd/lc_nexttrackedchange.svg |  435 
 icon-themes/elementary/cmd/lc_previoustrackedchange.png |binary
 icon-themes/elementary/cmd/lc_previoustrackedchange.svg |  435 
 icon-themes/elementary/cmd/lc_prevrecord.png|binary
 icon-themes/elementary/cmd/lc_prevrecord.svg|   57 +-
 icon-themes/elementary/cmd/lc_upsearch.png  |binary
 icon-themes/elementary/cmd/lc_upsearch.svg  |   47 +
 icon-themes/elementary/cmd/sc_accepttrackedchanges.png  |binary
 icon-themes/elementary/cmd/sc_accepttrackedchanges.svg  |  262 ++---
 icon-themes/elementary/cmd/sc_downsearch.png|binary
 icon-themes/elementary/cmd/sc_downsearch.svg|   99 +--
 icon-themes/elementary/cmd/sc_firstrecord.png   |binary
 icon-themes/elementary/cmd/sc_firstrecord.svg   |   64 +-
 icon-themes/elementary/cmd/sc_lastrecord.png|binary
 icon-themes/elementary/cmd/sc_lastrecord.svg|   64 +-
 icon-themes/elementary/cmd/sc_movedown.png  |binary
 icon-themes/elementary/cmd/sc_movedown.svg  |   56 +-
 icon-themes/elementary/cmd/sc_movedownsubitems.png  |binary
 icon-themes/elementary/cmd/sc_movedownsubitems.svg  |   28 -
 icon-themes/elementary/cmd/sc_movepagefirst.png |binary
 icon-themes/elementary/cmd/sc_movepagefirst.svg |   64 +-
 icon-themes/elementary/cmd/sc_movepagelast.png  |binary
 icon-themes/elementary/cmd/sc_movepagelast.svg  |   64 +-
 icon-themes/elementary/cmd/sc_moveup.png|binary
 icon-themes/elementary/cmd/sc_moveup.svg|   40 -
 icon-themes/elementary/cmd/sc_moveupsubitems.png|binary
 icon-themes/elementary/cmd/sc_moveupsubitems.svg|   53 +
 icon-themes/elementary/cmd/sc_nextrecord.png|binary
 icon-themes/elementary/cmd/sc_nextrecord.svg|   62 +-
 icon-themes/elementary/cmd/sc_nexttrackedchange.png |binary
 icon-themes/elementary/cmd/sc_nexttrackedchange.svg |  292 ++
 icon-themes/elementary/cmd/sc_previoustrackedchange.png |binary
 icon-themes/elementary/cmd/sc_previoustrackedchange.svg |  292 ++
 icon-themes/elementary/cmd/sc_prevrecord.png|binary
 icon-themes/elementary/cmd/sc_prevrecord.svg|   58 +-
 icon-themes/elementary/cmd/sc_rejecttrackedchange.png   |binary
 icon-themes/elementary/cmd/sc_rejecttrackedchange.svg   |  186 ++
 icon-themes/elementary/cmd/sc_trackchanges.png  |binary
 icon-themes/elementary/cmd/sc_trackchanges.svg  |  231 
 icon-themes/elementary/cmd/sc_trackchangesbar.png   |binary
 icon-themes/elementary/cmd/sc_trackchangesbar.svg   |  191 +++
 icon-themes/elementary/cmd/sc_upsearch.png  |binary
 icon-themes/elementary/cmd/sc_upsearch.svg  |   91 +--
 68 files changed, 3307 insertions(+), 584 deletions(-)

New commits:
commit d685d96c3479bb75dac9ffbdb537e1ac00d33295
Author: andreas kainz 
Date:   Mon Nov 27 01:03:47 2017 +0100

Elementary-icons update icon theme

Change-Id: Ica84d92564c52c4bdea8c71ccee55581a2538cf2
Reviewed-on: https://gerrit.libreoffice.org/45301
Reviewed-by: andreas_kainz 
Tested-by: andreas_kainz 

diff --git a/icon-themes/elementary/cmd/lc_downsearch

[Libreoffice-commits] core.git: cui/source

2017-11-26 Thread Mark Vecsernyes
 cui/source/dialogs/cuicharmap.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit eb384cf3792e3efc2473f26eee86b335804f2f9b
Author: Mark Vecsernyes 
Date:   Fri Nov 24 21:06:00 2017 +0100

tdf#113860 - Selecting a recent or favorite special character is not applied

Change-Id: Ia000e4d83b8012eff54647205f6e044920aed74b
Reviewed-on: https://gerrit.libreoffice.org/45259
Reviewed-by: Tamás Zolnai 
Tested-by: Tamás Zolnai 

diff --git a/cui/source/dialogs/cuicharmap.cxx 
b/cui/source/dialogs/cuicharmap.cxx
index 1058b70a795d..96d8cb73e3e6 100644
--- a/cui/source/dialogs/cuicharmap.cxx
+++ b/cui/source/dialogs/cuicharmap.cxx
@@ -214,7 +214,7 @@ void SvxCharacterMap::SetChar( sal_UCS4 c )
 
 sal_UCS4 SvxCharacterMap::GetChar() const
 {
-return m_pShowSet->GetSelectCharacter();
+   return (m_pShowChar->GetText()).toChar();
 }
 
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: framework/qa include/test qadevOOo/Jar_OOoRunner.mk qadevOOo/objdsc qadevOOo/tests sc/CppunitTest_sc_headerfootercontentobj.mk sc/Module_sc.mk sc/qa test/Library_subseq

2017-11-26 Thread Jens Carl
 framework/qa/complex/api_internal/api.lst|
1 
 include/test/sheet/xheaderfootercontent.hxx  |   
36 ++
 qadevOOo/Jar_OOoRunner.mk|
2 
 qadevOOo/objdsc/sc/com.sun.star.comp.office.ScHeaderFooterContentObj.csv |
3 
 qadevOOo/tests/java/ifc/sheet/_XHeaderFooterContent.java |   
73 -
 qadevOOo/tests/java/mod/_sc/ScHeaderFooterContentObj.java|  
135 --
 sc/CppunitTest_sc_headerfootercontentobj.mk  |  
105 +++
 sc/Module_sc.mk  |
1 
 sc/qa/extras/scheaderfootercontentobj.cxx|  
120 
 sc/qa/unoapi/sc_4.sce|
1 
 test/Library_subsequenttest.mk   |
1 
 test/source/sheet/xheaderfootercontent.cxx   |   
49 +++
 12 files changed, 312 insertions(+), 215 deletions(-)

New commits:
commit 2d609053adb2f078fa7aa3ccdf3758f2f01e478f
Author: Jens Carl 
Date:   Sat Nov 25 07:24:45 2017 +

tdf#45904 Move _XHeaderFooterContent Java tests to C++

Change-Id: I5e6ee9f44223c4b0b92ec32bb508d5b6c988689f
Reviewed-on: https://gerrit.libreoffice.org/45265
Tested-by: Jenkins 
Reviewed-by: Jens Carl 

diff --git a/framework/qa/complex/api_internal/api.lst 
b/framework/qa/complex/api_internal/api.lst
index fe472e824ea5..dae7278c29b0 100644
--- a/framework/qa/complex/api_internal/api.lst
+++ b/framework/qa/complex/api_internal/api.lst
@@ -96,7 +96,6 @@ job96=sc.ScFilterDescriptorBase
 job97=sc.ScFunctionListObj
 job98=sc.ScHeaderFieldObj
 job99=sc.ScHeaderFieldsObj
-job100=sc.ScHeaderFooterContentObj
 job101=sc.ScIndexEnumeration_CellAnnotationsEnumeration
 job102=sc.ScIndexEnumeration_CellAreaLinksEnumeration
 job103=sc.ScIndexEnumeration_DatabaseRangesEnumeration
diff --git a/include/test/sheet/xheaderfootercontent.hxx 
b/include/test/sheet/xheaderfootercontent.hxx
new file mode 100644
index ..64d3fea46341
--- /dev/null
+++ b/include/test/sheet/xheaderfootercontent.hxx
@@ -0,0 +1,36 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4; 
fill-column: 100 -*- */
+/*
+ * This file is part of the LibreOffice project.
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ */
+
+#ifndef INCLUDED_TEST_SHEET_XHEADERFOOTERCONTENT_HXX
+#define INCLUDED_TEST_SHEET_XHEADERFOOTERCONTENT_HXX
+
+#include 
+#include 
+
+#include 
+
+namespace apitest
+{
+class OOO_DLLPUBLIC_TEST XHeaderFooterContent
+{
+public:
+virtual css::uno::Reference init() = 0;
+
+void testGetCenterText();
+void testGetLeftText();
+void testGetRightText();
+
+protected:
+~XHeaderFooterContent() {}
+};
+}
+
+#endif // INCLUDED_TEST_SHEET_XHEADERFOOTERCONTENT_HXX
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab cinoptions=b1,g0,N-s 
cinkeys+=0=break: */
diff --git a/qadevOOo/Jar_OOoRunner.mk b/qadevOOo/Jar_OOoRunner.mk
index 0064c67a5dcf..ca7efb955432 100644
--- a/qadevOOo/Jar_OOoRunner.mk
+++ b/qadevOOo/Jar_OOoRunner.mk
@@ -604,7 +604,6 @@ $(eval $(call gb_Jar_add_sourcefiles,OOoRunner,\
 qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster \
 qadevOOo/tests/java/ifc/sheet/_XFormulaQuery \
 qadevOOo/tests/java/ifc/sheet/_XFunctionDescriptions \
-qadevOOo/tests/java/ifc/sheet/_XHeaderFooterContent \
 qadevOOo/tests/java/ifc/sheet/_XMultipleOperation \
 qadevOOo/tests/java/ifc/sheet/_XRangeSelection \
 qadevOOo/tests/java/ifc/sheet/_XRecentFunctions \
@@ -1043,7 +1042,6 @@ $(eval $(call gb_Jar_add_sourcefiles,OOoRunner,\
 qadevOOo/tests/java/mod/_sc/ScFunctionListObj \
 qadevOOo/tests/java/mod/_sc/ScHeaderFieldObj \
 qadevOOo/tests/java/mod/_sc/ScHeaderFieldsObj \
-qadevOOo/tests/java/mod/_sc/ScHeaderFooterContentObj \
 qadevOOo/tests/java/mod/_sc/ScHeaderFooterTextCursor \
 qadevOOo/tests/java/mod/_sc/ScHeaderFooterTextObj \
 qadevOOo/tests/java/mod/_sc/ScImportDescriptorBase \
diff --git 
a/qadevOOo/objdsc/sc/com.sun.star.comp.office.ScHeaderFooterContentObj.csv 
b/qadevOOo/objdsc/sc/com.sun.star.comp.office.ScHeaderFooterContentObj.csv
deleted file mode 100644
index e04311b56418..
--- a/qadevOOo/objdsc/sc/com.sun.star.comp.office.ScHeaderFooterContentObj.csv
+++ /dev/null
@@ -1,3 +0,0 @@
-"ScHeaderFooterContentObj";"com::sun::star::sheet::XHeaderFooterContent";"getLeftText()"
-"ScHeaderFooterContentObj";"com::sun::star::sheet::XHeaderFooterContent";"getCenterText()"
-"ScHeaderFooterContentObj";"com::sun::star::sheet::XHeaderFooterContent";"getRightText()"
diff --git a/qadevOOo/tests/java/ifc/sheet/_XHeaderFooterContent.java 
b/qadevOOo/tests/java/ifc/sh

[Libreoffice-commits] core.git: Branch 'libreoffice-6-0' - icon-themes/elementary

2017-11-26 Thread andreas kainz
 icon-themes/elementary/cmd/lc_downsearch.png|binary
 icon-themes/elementary/cmd/lc_downsearch.svg|   53 +
 icon-themes/elementary/cmd/lc_firstrecord.png   |binary
 icon-themes/elementary/cmd/lc_firstrecord.svg   |   67 +-
 icon-themes/elementary/cmd/lc_lastrecord.png|binary
 icon-themes/elementary/cmd/lc_lastrecord.svg|   56 +-
 icon-themes/elementary/cmd/lc_movedown.png  |binary
 icon-themes/elementary/cmd/lc_movedown.svg  |   53 +
 icon-themes/elementary/cmd/lc_movedownsubitems.png  |binary
 icon-themes/elementary/cmd/lc_movedownsubitems.svg  |   73 ++
 icon-themes/elementary/cmd/lc_movepagedown.png  |binary
 icon-themes/elementary/cmd/lc_movepagedown.svg  |   53 +
 icon-themes/elementary/cmd/lc_movepagefirst.png |binary
 icon-themes/elementary/cmd/lc_movepagefirst.svg |   67 +-
 icon-themes/elementary/cmd/lc_movepagelast.png  |binary
 icon-themes/elementary/cmd/lc_movepagelast.svg  |   56 +-
 icon-themes/elementary/cmd/lc_movepageup.png|binary
 icon-themes/elementary/cmd/lc_movepageup.svg|   47 +
 icon-themes/elementary/cmd/lc_moveup.png|binary
 icon-themes/elementary/cmd/lc_moveup.svg|   47 +
 icon-themes/elementary/cmd/lc_moveupsubitems.png|binary
 icon-themes/elementary/cmd/lc_moveupsubitems.svg|  103 ++-
 icon-themes/elementary/cmd/lc_nextrecord.png|binary
 icon-themes/elementary/cmd/lc_nextrecord.svg|   45 +
 icon-themes/elementary/cmd/lc_nexttrackedchange.png |binary
 icon-themes/elementary/cmd/lc_nexttrackedchange.svg |  435 
 icon-themes/elementary/cmd/lc_previoustrackedchange.png |binary
 icon-themes/elementary/cmd/lc_previoustrackedchange.svg |  435 
 icon-themes/elementary/cmd/lc_prevrecord.png|binary
 icon-themes/elementary/cmd/lc_prevrecord.svg|   57 +-
 icon-themes/elementary/cmd/lc_upsearch.png  |binary
 icon-themes/elementary/cmd/lc_upsearch.svg  |   47 +
 icon-themes/elementary/cmd/sc_accepttrackedchanges.png  |binary
 icon-themes/elementary/cmd/sc_accepttrackedchanges.svg  |  262 ++---
 icon-themes/elementary/cmd/sc_downsearch.png|binary
 icon-themes/elementary/cmd/sc_downsearch.svg|   99 +--
 icon-themes/elementary/cmd/sc_firstrecord.png   |binary
 icon-themes/elementary/cmd/sc_firstrecord.svg   |   64 +-
 icon-themes/elementary/cmd/sc_lastrecord.png|binary
 icon-themes/elementary/cmd/sc_lastrecord.svg|   64 +-
 icon-themes/elementary/cmd/sc_movedown.png  |binary
 icon-themes/elementary/cmd/sc_movedown.svg  |   56 +-
 icon-themes/elementary/cmd/sc_movedownsubitems.png  |binary
 icon-themes/elementary/cmd/sc_movedownsubitems.svg  |   28 -
 icon-themes/elementary/cmd/sc_movepagefirst.png |binary
 icon-themes/elementary/cmd/sc_movepagefirst.svg |   64 +-
 icon-themes/elementary/cmd/sc_movepagelast.png  |binary
 icon-themes/elementary/cmd/sc_movepagelast.svg  |   64 +-
 icon-themes/elementary/cmd/sc_moveup.png|binary
 icon-themes/elementary/cmd/sc_moveup.svg|   40 -
 icon-themes/elementary/cmd/sc_moveupsubitems.png|binary
 icon-themes/elementary/cmd/sc_moveupsubitems.svg|   53 +
 icon-themes/elementary/cmd/sc_nextrecord.png|binary
 icon-themes/elementary/cmd/sc_nextrecord.svg|   62 +-
 icon-themes/elementary/cmd/sc_nexttrackedchange.png |binary
 icon-themes/elementary/cmd/sc_nexttrackedchange.svg |  292 ++
 icon-themes/elementary/cmd/sc_previoustrackedchange.png |binary
 icon-themes/elementary/cmd/sc_previoustrackedchange.svg |  292 ++
 icon-themes/elementary/cmd/sc_prevrecord.png|binary
 icon-themes/elementary/cmd/sc_prevrecord.svg|   58 +-
 icon-themes/elementary/cmd/sc_rejecttrackedchange.png   |binary
 icon-themes/elementary/cmd/sc_rejecttrackedchange.svg   |  186 ++
 icon-themes/elementary/cmd/sc_trackchanges.png  |binary
 icon-themes/elementary/cmd/sc_trackchanges.svg  |  231 
 icon-themes/elementary/cmd/sc_trackchangesbar.png   |binary
 icon-themes/elementary/cmd/sc_trackchangesbar.svg   |  191 +++
 icon-themes/elementary/cmd/sc_upsearch.png  |binary
 icon-themes/elementary/cmd/sc_upsearch.svg  |   91 +--
 68 files changed, 3307 insertions(+), 584 deletions(-)

New commits:
commit ff6ab290b186904de2b73900fef3ae491db61350
Author: andreas kainz 
Date:   Mon Nov 27 01:03:47 2017 +0100

Elementary-icons update icon theme

Change-Id: Ica84d92564c52c4bdea8c71ccee55581a2538cf2
Reviewed-on: https://gerrit.libreoffice.org/45301
Reviewed-by: andreas_kainz 
Tested-by: andreas_kainz 
(cherry picked from commit d685d96c3479bb75dac9ffb

[Libreoffice-commits] core.git: Branch 'aoo/trunk' - unixODBC/Makefile unixODBC/Module_unixODBC.mk unixODBC/Package_inc.mk unixODBC/prj

2017-11-26 Thread Damjan Jovanovic
 unixODBC/Makefile   |   32 
 unixODBC/Module_unixODBC.mk |   30 ++
 unixODBC/Package_inc.mk |   30 ++
 unixODBC/prj/build.lst  |6 +++---
 unixODBC/prj/d.lst  |3 ---
 unixODBC/prj/makefile.mk|   44 
 6 files changed, 139 insertions(+), 6 deletions(-)

New commits:
commit 19c13a1a1cc3f275cd2b11bb82afe0a3b75392d6
Author: Damjan Jovanovic 
Date:   Mon Nov 27 05:09:40 2017 +

Port main/unixOBDC to gbuild.

Patch by: me

diff --git a/unixODBC/Makefile b/unixODBC/Makefile
new file mode 100644
index ..c1d144cbd4c9
--- /dev/null
+++ b/unixODBC/Makefile
@@ -0,0 +1,32 @@
+#**
+#  
+#  Licensed to the Apache Software Foundation (ASF) under one
+#  or more contributor license agreements.  See the NOTICE file
+#  distributed with this work for additional information
+#  regarding copyright ownership.  The ASF licenses this file
+#  to you under the Apache License, Version 2.0 (the
+#  "License"); you may not use this file except in compliance
+#  with the License.  You may obtain a copy of the License at
+#  
+#http://www.apache.org/licenses/LICENSE-2.0
+#  
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
+#  
+#**
+
+ifeq ($(strip $(SOLARENV)),)
+$(error No environment set!)
+endif
+
+gb_PARTIALBUILD := T
+GBUILDDIR := $(SOLARENV)/gbuild
+include $(GBUILDDIR)/gbuild.mk
+
+$(eval $(call gb_Module_make_global_targets,$(shell ls $(dir $(realpath 
$(firstword $(MAKEFILE_LIST/Module*.mk)))
+
+# vim: set noet sw=4 ts=4:
diff --git a/unixODBC/Module_unixODBC.mk b/unixODBC/Module_unixODBC.mk
new file mode 100644
index ..64490d02d5ae
--- /dev/null
+++ b/unixODBC/Module_unixODBC.mk
@@ -0,0 +1,30 @@
+#**
+#  
+#  Licensed to the Apache Software Foundation (ASF) under one
+#  or more contributor license agreements.  See the NOTICE file
+#  distributed with this work for additional information
+#  regarding copyright ownership.  The ASF licenses this file
+#  to you under the Apache License, Version 2.0 (the
+#  "License"); you may not use this file except in compliance
+#  with the License.  You may obtain a copy of the License at
+#  
+#http://www.apache.org/licenses/LICENSE-2.0
+#  
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
+#  
+#**
+
+
+
+$(eval $(call gb_Module_Module,unixODBC))
+
+$(eval $(call gb_Module_add_targets,unixODBC,\
+   Package_inc \
+))
+
+# vim: set noet sw=4 ts=4:
diff --git a/unixODBC/Package_inc.mk b/unixODBC/Package_inc.mk
new file mode 100644
index ..c7fdc99911c8
--- /dev/null
+++ b/unixODBC/Package_inc.mk
@@ -0,0 +1,30 @@
+#**
+#  
+#  Licensed to the Apache Software Foundation (ASF) under one
+#  or more contributor license agreements.  See the NOTICE file
+#  distributed with this work for additional information
+#  regarding copyright ownership.  The ASF licenses this file
+#  to you under the Apache License, Version 2.0 (the
+#  "License"); you may not use this file except in compliance
+#  with the License.  You may obtain a copy of the License at
+#  
+#http://www.apache.org/licenses/LICENSE-2.0
+#  
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
+#  
+#**
+
+
+
+$(eval $(call gb_Package_Package,unixODBC_inc,$(SRCDIR)/unixODBC))
+
+$(eval $(call 
gb_Package_add_file,unixODBC_inc,inc/external/odbc/iodbcunix.h,inc/iodbcunix.h))
+$(eval $(call 
gb_Package_add_file,unixODBC_inc,inc/external/odbc/sql.h,inc/sql.h))
+$(eval $(call 
gb_Package_add_file,unixODBC_inc,inc/external/odbc/sqlext.h,inc/sqlext.h))
+$(eval $(call 
gb_Package_add_file,unixODBC_inc,inc/external/odbc/sqltypes.h,inc/sqltypes.h))
+$(eval $(call 
gb_Package_add_file,unixODBC_inc,inc/external/odbc/sqlucode.h,inc

[Libreoffice-commits] libcdr.git: src/lib

2017-11-26 Thread Miklos Vajna
 src/lib/CMXParser.cpp |5 +
 1 file changed, 1 insertion(+), 4 deletions(-)

New commits:
commit e646d40f53bfb112abfd8153268665f73153b00c
Author: Miklos Vajna 
Date:   Mon Nov 27 08:31:23 2017 +0100

CMXParser: remove never read length / maxLength

Technically both were read and written at least once so the compiler did
not warn on them; but in practice these are unused. Leave the readU32()
call there, though -- as it has a side effect.

Change-Id: I24240ef216b6ce18d792594ff77fad46e6688508

diff --git a/src/lib/CMXParser.cpp b/src/lib/CMXParser.cpp
index 9cbfecc..57a6f5e 100644
--- a/src/lib/CMXParser.cpp
+++ b/src/lib/CMXParser.cpp
@@ -345,10 +345,7 @@ void 
libcdr::CMXParser::readIxmr(librevenge::RVNGInputStream *input)
   unsigned fourCC = readU32(input, m_bigEndian);
   if (CDR_FOURCC_ixmr != fourCC)
 return;
-  unsigned length = readU32(input, m_bigEndian);
-  const unsigned long maxLength = getRemainingLength(input);
-  if (length > maxLength)
-length = maxLength;
+  readU32(input, m_bigEndian); // Length
 
   readU16(input, m_bigEndian); // Master ID
   readU16(input, m_bigEndian); // Size
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: svl/source

2017-11-26 Thread Dennis Francis
 svl/source/numbers/zforlist.cxx |   67 
 1 file changed, 67 insertions(+)

New commits:
commit b1f829dae5cacc595f78c9647ce8487ca5af
Author: Dennis Francis 
Date:   Wed Nov 22 16:46:46 2017 +0530

Make SvNumberFormatter public methods threadsafe

This is a requirement due to the recent threading work done
on calc formulagroup interpreter.

Change-Id: I5d567b4b957a4d86303f6a86b14d1cbfc730beda
Reviewed-on: https://gerrit.libreoffice.org/45085
Tested-by: Jenkins 
Reviewed-by: Dennis Francis 

diff --git a/svl/source/numbers/zforlist.cxx b/svl/source/numbers/zforlist.cxx
index b38c3c317545..a6e7af89562f 100644
--- a/svl/source/numbers/zforlist.cxx
+++ b/svl/source/numbers/zforlist.cxx
@@ -326,6 +326,7 @@ void SvNumberFormatter::ImpConstruct( LanguageType eLang )
 
 void SvNumberFormatter::ChangeIntl(LanguageType eLnge)
 {
+::osl::MutexGuard aGuard( GetMutex() );
 if (ActLnge != eLnge)
 {
 ActLnge = eLnge;
@@ -374,11 +375,13 @@ SvNumberFormatterRegistry_Impl& 
SvNumberFormatter::GetFormatterRegistry()
 
 void SvNumberFormatter::SetColorLink( const Link& 
rColorTableCallBack )
 {
+::osl::MutexGuard aGuard( GetMutex() );
 aColorLink = rColorTableCallBack;
 }
 
 Color* SvNumberFormatter::GetUserDefColor(sal_uInt16 nIndex)
 {
+::osl::MutexGuard aGuard( GetMutex() );
 if( aColorLink.IsSet() )
 {
 return aColorLink.Call(nIndex);
@@ -393,32 +396,38 @@ void SvNumberFormatter::ChangeNullDate(sal_uInt16 nDay,
sal_uInt16 nMonth,
sal_Int16 nYear)
 {
+::osl::MutexGuard aGuard( GetMutex() );
 pFormatScanner->ChangeNullDate(nDay, nMonth, nYear);
 pStringScanner->ChangeNullDate(nDay, nMonth, nYear);
 }
 
 const Date& SvNumberFormatter::GetNullDate() const
 {
+::osl::MutexGuard aGuard( GetMutex() );
 return pFormatScanner->GetNullDate();
 }
 
 void SvNumberFormatter::ChangeStandardPrec(short nPrec)
 {
+::osl::MutexGuard aGuard( GetMutex() );
 pFormatScanner->ChangeStandardPrec(nPrec);
 }
 
 void SvNumberFormatter::SetNoZero(bool bNZ)
 {
+::osl::MutexGuard aGuard( GetMutex() );
 bNoZero = bNZ;
 }
 
 sal_uInt16 SvNumberFormatter::GetStandardPrec() const
 {
+::osl::MutexGuard aGuard( GetMutex() );
 return pFormatScanner->GetStandardPrec();
 }
 
 bool SvNumberFormatter::GetNoZero() const
 {
+::osl::MutexGuard aGuard( GetMutex() );
 return bNoZero;
 }
 
@@ -547,6 +556,7 @@ bool SvNumberFormatter::IsDecimalSep( const OUString& rStr 
) const
 
 bool SvNumberFormatter::IsTextFormat(sal_uInt32 F_Index) const
 {
+::osl::MutexGuard aGuard( GetMutex() );
 const SvNumberformat* pFormat = GetFormatEntry(F_Index);
 
 return pFormat && pFormat->IsTextFormat();
@@ -558,6 +568,7 @@ bool SvNumberFormatter::PutEntry(OUString& rString,
  sal_uInt32& nKey,  // format key
  LanguageType eLnge)
 {
+::osl::MutexGuard aGuard( GetMutex() );
 nKey = 0;
 if (rString.isEmpty()) // empty string
 {
@@ -626,6 +637,7 @@ bool SvNumberFormatter::PutandConvertEntry(OUString& 
rString,
LanguageType eNewLnge,
bool bForExcelExport )
 {
+::osl::MutexGuard aGuard( GetMutex() );
 bool bRes;
 if (eNewLnge == LANGUAGE_DONTKNOW)
 {
@@ -644,6 +656,7 @@ bool SvNumberFormatter::PutandConvertEntrySystem(OUString& 
rString,
  LanguageType eLnge,
  LanguageType eNewLnge)
 {
+::osl::MutexGuard aGuard( GetMutex() );
 bool bRes;
 if (eNewLnge == LANGUAGE_DONTKNOW)
 {
@@ -659,6 +672,7 @@ sal_uInt32 SvNumberFormatter::GetIndexPuttingAndConverting( 
OUString & rString,
 LanguageType 
eSysLnge, short & rType,
 bool & 
rNewInserted, sal_Int32 & rCheckPos )
 {
+::osl::MutexGuard aGuard( GetMutex() );
 sal_uInt32 nKey = NUMBERFORMAT_ENTRY_NOT_FOUND;
 rNewInserted = false;
 rCheckPos = 0;
@@ -732,12 +746,14 @@ sal_uInt32 
SvNumberFormatter::GetIndexPuttingAndConverting( OUString & rString,
 
 void SvNumberFormatter::DeleteEntry(sal_uInt32 nKey)
 {
+::osl::MutexGuard aGuard( GetMutex() );
 delete aFTable[nKey];
 aFTable.erase(nKey);
 }
 
 void SvNumberFormatter::GetUsedLanguages( std::vector& rList )
 {
+::osl::MutexGuard aGuard( GetMutex() );
 rList.clear();
 
 sal_uInt32 nOffset = 0;
@@ -756,6 +772,7 @@ void SvNumberFormatter::GetUsedLanguages( 
std::vector& rList )
 void SvNumberFormatter::FillKeywordTable( NfKeywordTable& rKeywords,
   LanguageType eLang )
 {
+::osl::MutexGuard aGuard( GetMutex() )
diff --git a/xmloff/source/chart/SchXMLChartContext.cxx 
b/xmloff/source/chart/SchXMLChartContext.cxx
index c4894273020c..0bc45256a597 100644
--- a/xmloff/source/chart/SchXMLChartContext.cxx
+++ b/xmloff/source/chart/SchXMLChartContext.cxx
@@ -472,9 +472,9 @@ struct NewDonutSeries
 m_aPointStyles[nPointIndex]=rStyleName;
 }
 
-::std::list< DataRowPointStyle > creatStyleList()
+::std::vector< DataRowPointStyle > creatStyleVector()
 {
-::std::list< DataRowPointStyle > aRet;
+::std::vector< DataRowPointStyle > aRet;
 
 DataRowPointStyle aSeriesStyle( DataRowPointStyle::DATA_SERIES
 , m_xSeries, -1, 1, msStyleName, mnAttachedAxis );
@@ -502,11 +502,11 @@ struct NewDonutSeries
 }
 };
 
-void lcl_swapPointAndSeriesStylesForDonutCharts( ::std::list< 
DataRowPointStyle >& rStyleList
+void lcl_swapPointAndSeriesStylesForDonutCharts( ::std::vector< 
DataRowPointStyle >& rStyleVector
 , const ::std::map< css::uno::Reference< css::chart2::XDataSeries> , 
sal_Int32 >& rSeriesMap )
 {
-::std::list< DataRowPointStyle >::iterator aIt(rStyleList.begin());
-::std::list< DataRowPointStyle >::iterator aEnd(rStyleList.end());
+::std::vector< DataRowPointStyle >::iterator aIt(rStyleVector.begin());
+::std::vector< DataRowPointStyle >::iterator aEnd(rStyleVector.end());
 
 //detect old series count
 //and add old series to aSeriesMap
@@ -516,7 +516,7 @@ void lcl_swapPointAndSeriesStylesForDonutCharts( 
::std::list< DataRowPointStyle
 {
 sal_Int32 nMaxOldSeriesIndex = 0;
 sal_Int32 nOldSeriesIndex = 0;
-for( aIt = rStyleList.begin(); aIt != aEnd; ++aIt )
+for( aIt = rStyleVector.begin(); aIt != aEnd; ++aIt )
 {
 DataRowPointStyle aStyle(*aIt);
 if(aStyle.meType == DataRowPointStyle::DATA_SERIES &&
@@ -552,7 +552,7 @@ void lcl_swapPointAndSeriesStylesForDonutCharts( 
::std::list< DataRowPointStyle
 }
 
 //overwrite attached axis information according to old series styles
-for( aIt = rStyleList.begin(); aIt != aEnd; ++aIt )
+for( aIt = rStyleVector.begin(); aIt != aEnd; ++aIt )
 {
 DataRowPointStyle aStyle(*aIt);
 if(aStyle.meType == DataRowPointStyle::DATA_SERIES )
@@ -564,7 +564,7 @@ void lcl_swapPointAndSeriesStylesForDonutCharts( 
::std::list< DataRowPointStyle
 }
 
 //overwrite new series style names with old series style name information
-for( aIt = rStyleList.begin(); aIt != aEnd; ++aIt )
+for( aIt = rStyleVector.begin(); aIt != aEnd; ++aIt )
 {
 DataRowPointStyle aStyle(*aIt);
 if( aStyle.meType == DataRowPointStyle::DATA_SERIES )
@@ -584,7 +584,7 @@ void lcl_swapPointAndSeriesStylesForDonutCharts( 
::std::list< DataRowPointStyle
 }
 
 //overwrite new series style names with point style name information
-for( aIt = rStyleList.begin(); aIt != aEnd; ++aIt )
+for( aIt = rStyleVector.begin(); aIt != aEnd; ++aIt )
 {
 DataRowPointStyle aStyle(*aIt);
 if( aStyle.meType == DataRowPointStyle::DATA_POINT )
@@ -608,15 +608,15 @@ void lcl_swapPointAndSeriesStylesForDonutCharts( 
::std::list< DataRowPointStyle
 }
 }
 
-//put information from aNewSeriesVector to output parameter rStyleList
-rStyleList.clear();
+//put information from aNewSeriesVector to output parameter rStyleVector
+rStyleVector.clear();
 
 ::std::vector< NewDonutSeries >::iterator aNewSeriesIt( 
aNewSeriesVector.begin() );
 ::std::vector< NewDonutSeries >::iterator aNewSeriesEnd( 
aNewSeriesVector.end() );
 for( ;aNewSeriesIt!=aNewSeriesEnd; ++aNewSeriesIt)
 {
-::std::list< DataRowPointStyle > aList( aNewSeriesIt->creatStyleList() 
);
-rStyleList.insert(rStyleList.end(),aList.begin(),aList.end());
+::std::vector< DataRowPointStyle > aVector( 
aNewSeriesIt->creatStyleVector() );
+rStyleVector.insert(rStyleVector.end(),aVector.begin(),aVector.end());
 }
 }
 
@@ -895,7 +89

[Libreoffice-commits] online.git: kit/Kit.cpp

2017-11-26 Thread Rene Engelhard
 kit/Kit.cpp |3 +++
 1 file changed, 3 insertions(+)

New commits:
commit af7685e49907f5b520ee9288b12f82d633ce9423
Author: Rene Engelhard 
Date:   Sun Nov 26 13:14:24 2017 +

include 

kit/Kit.cpp:1688:13: warning: In the GNU C Library, "makedev" is defined
 by . For historical compatibility, it is
 currently defined by  as well, but we plan to
 remove this soon. To use "makedev", include 
 directly. If you did not intend to use a system-defined macro
 "makedev", you should undefine it after including .
